unit conv;

interface

type
	TTwoWayFilter =
		class
		private
				shiftjis : boolean;
				ed, sf, df : string;
		public
			constructor create( editor, srcfile, dstfile : string; sjis : boolean );
			procedure run; virtual;
		protected
			function encodeLine( s : widestring ) : widestring; virtual;abstract;
			function decodeLine( s : wideString ) : wideString; virtual;abstract;
		end;

	TKanjiFilter =
		class( TTwoWayFilter )
		protected
			function encodeLine( s : widestring ) : widestring; override;
			function decodeLine( s : wideString ) : wideString; override;
		end;

function isJA( c : widechar ) : boolean;
implementation
uses
	forms, dialogs, Windows, sysutils;
var
  ja: array [0..2047] of cardinal;

constructor TTwoWayFilter.create( editor, srcfile, dstfile : string; sjis : boolean );
begin
	inherited create;
	ed := editor;
	sf := srcfile;
	df := dstfile;
	shiftjis := sjis;
end;


procedure TTwoWayFilter.run;
		// ^ꂽGR[hfR[hăe|t@Cɏo
		// ^tH[}bgUTF8/UTF8N/SHIFTJIŜꂩ
	procedure decode();
	var
	  fi, fo: TextFile;
	  S: string;
	  ws, ds: widestring;
	begin
		AssignFile(fi, sf ); // p[^ŗ^ꂽt@C
		Reset(fi);
		assignFile( fo, df );                	// e|t@C
		rewrite(fo);
		write(fo, #$ef, #$bb, #$bf);           	// BOMo
		while not eof(fi) do begin
			Readln(fi, S);
			if shiftjis then
				s := ansiToUtf8( s );
			ws := system.Utf8Decode( S );     		// UTF8UCF2ɕϊ
			if ( length(ws) >= 1 ) and ( ws[1] = widechar( $feff ) )then
				ws := copy( ws, 2, length(ws) );	// ͂BOM폜
			ds := decodeLine( ws );        			// 1sfR[h
			s := system.UTF8Encode( ds );     		// UCF2UTF8ɕϊ
			writeln(fo, s );
		end;

		CloseFile(fi);
		closeFile(fo);

	end;

		// ҏW̃e|t@C̃GR[hɖ߂B
		// ߂tH[}bgUTF8N/SHIFTJIŜꂩ
	procedure encode();
		var
	  fi, fo: TextFile;
	  S: string;
	  ws, ds: widestring;
	begin
		AssignFile(fi, df); 					// e|t@C
		Reset(fi);
		assignFile( fo, sf );
		rewrite(fo);
		while not eof(fi) do begin
			Readln(fi, S);
			ws := system.Utf8Decode( S );     		// UTF8UCF2ɕϊ
			if ( length(ws) >= 1 ) and ( ws[1] = widechar( $feff ) )then
				ws := copy( ws, 2, length(ws) );	// BOM폜
			ds := encodeLine( ws );        			// 1sGR[h
			s := system.UTF8Encode( ds );     		// UCF2UTF8ɕϊ
			if shiftjis then
				s := utf8ToAnsi( s );
			writeln( fo, s );
		end;

		CloseFile(fi);
		closeFile(fo);
	end;

		// http://www.eva.hi-ho.ne.jp/taketani/delphi/system.shtml#0003 q
	procedure callEditor;
	var
	  ret: Boolean;
	  ecode: Integer;
	  StartupInfo: TStartupInfo;
	  ProcessInfo: TProcessInformation;
	  commandline : array [ 0 .. 511] of char;
	  s : string;
	  i : integer;
	begin
	  // \Ԃݒ
	  with StartupInfo do begin
		// ̍\̂̃TCYw
		cb := SizeOf(TStartupInfo);
		// EBhËʒuw
		dwX := 0;
		dwY := 0;
		// EBhẼTCYw
		dwXSize := 640;
		dwYSize := 480;
		// EBhE̕\Ԃw
		wShowWindow := SW_SHOWNORMAL;
		// LȐݒ荀ڂw
		dwFlags := STARTF_USESHOWWINDOW
		  or STARTF_USESIZE or STARTF_USEPOSITION;
		// ȊO̍ڂ
		lpReserved := nil;
		lpDesktop  := nil;
		lpTitle    := nil;
		cbReserved2 := 0;
		lpReserved2 := nil;
	  end;

	  s := ed + ' ' + df;
	  for i := 1 to length( s ) do
		commandline[ i-1 ] := s[i];
	  commandline[length(s)] := #0;
	  // s
	  ret := CreateProcess(
		nil,                        // st@C
		@commandline,			    // R}hC
		nil,                        // vZX̃ZLeB
		nil,                        // Xbh̃ZLeB
		False,                      // evZXnhp邩
		CREATE_DEFAULT_ERROR_MODE,  // D揇ʂƃvZX̐쐧
		nil,                        // ϐubNւ̃|C^
		nil,                        // JgfBNg
		StartupInfo,                // EBhȆ
		ProcessInfo                 // VvZX̏󂯎\
	  );
	  // G[`FbN
	  if not ret then
		ShowMessage('sł܂ (' + IntToStr(GetLastError) + ')');

	  // {^̖ƃbZ[W\
	  Application.ProcessMessages;

	  // I҂(10b҂)
	  while true do  begin
		ecode := WaitForSingleObject(ProcessInfo.hProcess, 100);
		if ecode = WAIT_OBJECT_0 then break;
		Application.ProcessMessages;
	  end;

	end;

begin		// TTowWayFilter.run;
	decode;			// input -> output
	callEditor;		// edit output
	encode;			// output -> input
end;



//--------------------------------------------------------------------------
function TKanjiFilter.encodeLine( s : widestring ) : widestring;
var
	i : integer;
	d : widestring;
begin
	d := '';
	for i := 1 to length( s ) do begin
		if isJa( s[i] ) then
			d := d + s[i]               // {Ȃ炻̂܂܏o
		else
			d := d + '&#x' + inttohex( ord(s[i]),4) + ';';  //{łȂΐlQƂɕϊ
	end;
	encodeLine := d;
end;


function TKanjiFilter.decodeLine( s : widestring ) : widestring;
var
	d : widestring;
	st, term : integer;
	vstr : widestring;
	value : integer;
begin

	d := '';
	while  0 < length( s ) do begin
		st := pos( '&#', s );     				// lQƂ̊Jnʒu
		if st > 0  then begin       			// lQƂgĂB
			d := d + copy( s, 1, st - 1 );		// lQƈȑÕf[^ۑ
			s := copy( s, st, length( s ) );	// lQƂ̕ɂ
			term := pos( ';', s );

			if term = 0 then begin            	// ILT
				d := d + s;                     // ȂȂΌ
				s := '';                        // ̂܂܃Rs[ďI
			end
			else begin                       	// ILꍇ
				try
					vstr := copy( s, 3, term - 3 );	// 16îƂɂ͓'x'邪OK
					value := strtoint( vstr );
					d := d + widechar( value );     // unicodeɕϊ
				except
					on e:EConvertError do
						d := d + copy( s, 1, term );
				end;
				s := copy( s, term + 1, length(s) );
			end;
		end
		else begin     				// lQƂȂꍇ͂̂܂܃Rs[
			d := d + s;
			s := '';
		end;
	end;      		// end of while
	decodeLine := d;
end;

//--------------------------------------------------------------------------



	// rbg}bvANZXq
procedure access(i : integer; var index, mask : cardinal );
begin
	index := i shr 5;
	mask := 1 shl ( i and 31 )
end;

	// rbg}bv̎wLN^R[h1ɂ
procedure setJa( c : word );
	var
		index, mask : cardinal;
begin
	access( ord(c), index, mask );
	ja[index] := ja[index] or mask;
end;


	// ₢킹̂LN^R[h͓{ꂩH
function isJA( c : widechar ) : boolean;
	var
		index, mask : cardinal;
begin
	access( ord(c), index, mask );
	isJA := ( ja[index] and mask ) <> 0;
end;

var
	i : integer;
begin
		// rbg}bv̏
	for i := 0 to 2047 do
		ja [i] := 0;

		// JIS 0208ASCII(128̈󎚉\)̗̈1ɂB
	setJa($0020);
	setJa($0021);
	setJa($0022);
	setJa($0023);
	setJa($0024);
	setJa($0025);
	setJa($0026);
	setJa($0027);
	setJa($0028);
	setJa($0029);
	setJa($002A);
	setJa($002B);
	setJa($002C);
	setJa($002D);
	setJa($002E);
	setJa($002F);
	setJa($0030);
	setJa($0031);
	setJa($0032);
	setJa($0033);
	setJa($0034);
	setJa($0035);
	setJa($0036);
	setJa($0037);
	setJa($0038);
	setJa($0039);
	setJa($003A);
	setJa($003B);
	setJa($003C);
	setJa($003D);
	setJa($003E);
	setJa($003F);
	setJa($0040);
	setJa($0041);
	setJa($0042);
	setJa($0043);
	setJa($0044);
	setJa($0045);
	setJa($0046);
	setJa($0047);
	setJa($0048);
	setJa($0049);
	setJa($004A);
	setJa($004B);
	setJa($004C);
	setJa($004D);
	setJa($004E);
	setJa($004F);
	setJa($0050);
	setJa($0051);
	setJa($0052);
	setJa($0053);
	setJa($0054);
	setJa($0055);
	setJa($0056);
	setJa($0057);
	setJa($0058);
	setJa($0059);
	setJa($005A);
	setJa($005B);
	setJa($00A5);
	setJa($005D);
	setJa($005E);
	setJa($005F);
	setJa($0060);
	setJa($0061);
	setJa($0062);
	setJa($0063);
	setJa($0064);
	setJa($0065);
	setJa($0066);
	setJa($0067);
	setJa($0068);
	setJa($0069);
	setJa($006A);
	setJa($006B);
	setJa($006C);
	setJa($006D);
	setJa($006E);
	setJa($006F);
	setJa($0070);
	setJa($0071);
	setJa($0072);
	setJa($0073);
	setJa($0074);
	setJa($0075);
	setJa($0076);
	setJa($0077);
	setJa($0078);
	setJa($0079);
	setJa($007A);
	setJa($007B);
	setJa($007C);
	setJa($007D);
	setJa($007E);
	setJa($203E);
	setJa($3000);
	setJa($3001);
	setJa($3002);
	setJa($FF0C);
	setJa($FF0E);
	setJa($30FB);
	setJa($FF1A);
	setJa($FF1B);
	setJa($FF1F);
	setJa($FF01);
	setJa($309B);
	setJa($309C);
	setJa($00B4);
	setJa($FF40);
	setJa($00A8);
	setJa($FF3E);
	setJa($FFE3);
	setJa($FF3F);
	setJa($30FD);
	setJa($30FE);
	setJa($309D);
	setJa($309E);
	setJa($3003);
	setJa($4EDD);
	setJa($3005);
	setJa($3006);
	setJa($3007);
	setJa($30FC);
	setJa($2015);
	setJa($2010);
	setJa($FF0F);
	setJa($005C);
	setJa($301C);
	setJa($2016);
	setJa($FF5C);
	setJa($2026);
	setJa($2025);
	setJa($2018);
	setJa($2019);
	setJa($201C);
	setJa($201D);
	setJa($FF08);
	setJa($FF09);
	setJa($3014);
	setJa($3015);
	setJa($FF3B);
	setJa($FF3D);
	setJa($FF5B);
	setJa($FF5D);
	setJa($3008);
	setJa($3009);
	setJa($300A);
	setJa($300B);
	setJa($300C);
	setJa($300D);
	setJa($300E);
	setJa($300F);
	setJa($3010);
	setJa($3011);
	setJa($FF0B);
	setJa($2212);
	setJa($00B1);
	setJa($00D7);
	setJa($00F7);
	setJa($FF1D);
	setJa($2260);
	setJa($FF1C);
	setJa($FF1E);
	setJa($2266);
	setJa($2267);
	setJa($221E);
	setJa($2234);
	setJa($2642);
	setJa($2640);
	setJa($00B0);
	setJa($2032);
	setJa($2033);
	setJa($2103);
	setJa($FFE5);
	setJa($FF04);
	setJa($00A2);
	setJa($00A3);
	setJa($FF05);
	setJa($FF03);
	setJa($FF06);
	setJa($FF0A);
	setJa($FF20);
	setJa($00A7);
	setJa($2606);
	setJa($2605);
	setJa($25CB);
	setJa($25CF);
	setJa($25CE);
	setJa($25C7);
	setJa($25C6);
	setJa($25A1);
	setJa($25A0);
	setJa($25B3);
	setJa($25B2);
	setJa($25BD);
	setJa($25BC);
	setJa($203B);
	setJa($3012);
	setJa($2192);
	setJa($2190);
	setJa($2191);
	setJa($2193);
	setJa($3013);
	setJa($2208);
	setJa($220B);
	setJa($2286);
	setJa($2287);
	setJa($2282);
	setJa($2283);
	setJa($222A);
	setJa($2229);
	setJa($2227);
	setJa($2228);
	setJa($00AC);
	setJa($21D2);
	setJa($21D4);
	setJa($2200);
	setJa($2203);
	setJa($2220);
	setJa($22A5);
	setJa($2312);
	setJa($2202);
	setJa($2207);
	setJa($2261);
	setJa($2252);
	setJa($226A);
	setJa($226B);
	setJa($221A);
	setJa($223D);
	setJa($221D);
	setJa($2235);
	setJa($222B);
	setJa($222C);
	setJa($212B);
	setJa($2030);
	setJa($266F);
	setJa($266D);
	setJa($266A);
	setJa($2020);
	setJa($2021);
	setJa($00B6);
	setJa($25EF);
	setJa($FF10);
	setJa($FF11);
	setJa($FF12);
	setJa($FF13);
	setJa($FF14);
	setJa($FF15);
	setJa($FF16);
	setJa($FF17);
	setJa($FF18);
	setJa($FF19);
	setJa($FF21);
	setJa($FF22);
	setJa($FF23);
	setJa($FF24);
	setJa($FF25);
	setJa($FF26);
	setJa($FF27);
	setJa($FF28);
	setJa($FF29);
	setJa($FF2A);
	setJa($FF2B);
	setJa($FF2C);
	setJa($FF2D);
	setJa($FF2E);
	setJa($FF2F);
	setJa($FF30);
	setJa($FF31);
	setJa($FF32);
	setJa($FF33);
	setJa($FF34);
	setJa($FF35);
	setJa($FF36);
	setJa($FF37);
	setJa($FF38);
	setJa($FF39);
	setJa($FF3A);
	setJa($FF41);
	setJa($FF42);
	setJa($FF43);
	setJa($FF44);
	setJa($FF45);
	setJa($FF46);
	setJa($FF47);
	setJa($FF48);
	setJa($FF49);
	setJa($FF4A);
	setJa($FF4B);
	setJa($FF4C);
	setJa($FF4D);
	setJa($FF4E);
	setJa($FF4F);
	setJa($FF50);
	setJa($FF51);
	setJa($FF52);
	setJa($FF53);
	setJa($FF54);
	setJa($FF55);
	setJa($FF56);
	setJa($FF57);
	setJa($FF58);
	setJa($FF59);
	setJa($FF5A);
	setJa($3041);
	setJa($3042);
	setJa($3043);
	setJa($3044);
	setJa($3045);
	setJa($3046);
	setJa($3047);
	setJa($3048);
	setJa($3049);
	setJa($304A);
	setJa($304B);
	setJa($304C);
	setJa($304D);
	setJa($304E);
	setJa($304F);
	setJa($3050);
	setJa($3051);
	setJa($3052);
	setJa($3053);
	setJa($3054);
	setJa($3055);
	setJa($3056);
	setJa($3057);
	setJa($3058);
	setJa($3059);
	setJa($305A);
	setJa($305B);
	setJa($305C);
	setJa($305D);
	setJa($305E);
	setJa($305F);
	setJa($3060);
	setJa($3061);
	setJa($3062);
	setJa($3063);
	setJa($3064);
	setJa($3065);
	setJa($3066);
	setJa($3067);
	setJa($3068);
	setJa($3069);
	setJa($306A);
	setJa($306B);
	setJa($306C);
	setJa($306D);
	setJa($306E);
	setJa($306F);
	setJa($3070);
	setJa($3071);
	setJa($3072);
	setJa($3073);
	setJa($3074);
	setJa($3075);
	setJa($3076);
	setJa($3077);
	setJa($3078);
	setJa($3079);
	setJa($307A);
	setJa($307B);
	setJa($307C);
	setJa($307D);
	setJa($307E);
	setJa($307F);
	setJa($3080);
	setJa($3081);
	setJa($3082);
	setJa($3083);
	setJa($3084);
	setJa($3085);
	setJa($3086);
	setJa($3087);
	setJa($3088);
	setJa($3089);
	setJa($308A);
	setJa($308B);
	setJa($308C);
	setJa($308D);
	setJa($308E);
	setJa($308F);
	setJa($3090);
	setJa($3091);
	setJa($3092);
	setJa($3093);
	setJa($30A1);
	setJa($30A2);
	setJa($30A3);
	setJa($30A4);
	setJa($30A5);
	setJa($30A6);
	setJa($30A7);
	setJa($30A8);
	setJa($30A9);
	setJa($30AA);
	setJa($30AB);
	setJa($30AC);
	setJa($30AD);
	setJa($30AE);
	setJa($30AF);
	setJa($30B0);
	setJa($30B1);
	setJa($30B2);
	setJa($30B3);
	setJa($30B4);
	setJa($30B5);
	setJa($30B6);
	setJa($30B7);
	setJa($30B8);
	setJa($30B9);
	setJa($30BA);
	setJa($30BB);
	setJa($30BC);
	setJa($30BD);
	setJa($30BE);
	setJa($30BF);
	setJa($30C0);
	setJa($30C1);
	setJa($30C2);
	setJa($30C3);
	setJa($30C4);
	setJa($30C5);
	setJa($30C6);
	setJa($30C7);
	setJa($30C8);
	setJa($30C9);
	setJa($30CA);
	setJa($30CB);
	setJa($30CC);
	setJa($30CD);
	setJa($30CE);
	setJa($30CF);
	setJa($30D0);
	setJa($30D1);
	setJa($30D2);
	setJa($30D3);
	setJa($30D4);
	setJa($30D5);
	setJa($30D6);
	setJa($30D7);
	setJa($30D8);
	setJa($30D9);
	setJa($30DA);
	setJa($30DB);
	setJa($30DC);
	setJa($30DD);
	setJa($30DE);
	setJa($30DF);
	setJa($30E0);
	setJa($30E1);
	setJa($30E2);
	setJa($30E3);
	setJa($30E4);
	setJa($30E5);
	setJa($30E6);
	setJa($30E7);
	setJa($30E8);
	setJa($30E9);
	setJa($30EA);
	setJa($30EB);
	setJa($30EC);
	setJa($30ED);
	setJa($30EE);
	setJa($30EF);
	setJa($30F0);
	setJa($30F1);
	setJa($30F2);
	setJa($30F3);
	setJa($30F4);
	setJa($30F5);
	setJa($30F6);
	setJa($0391);
	setJa($0392);
	setJa($0393);
	setJa($0394);
	setJa($0395);
	setJa($0396);
	setJa($0397);
	setJa($0398);
	setJa($0399);
	setJa($039A);
	setJa($039B);
	setJa($039C);
	setJa($039D);
	setJa($039E);
	setJa($039F);
	setJa($03A0);
	setJa($03A1);
	setJa($03A3);
	setJa($03A4);
	setJa($03A5);
	setJa($03A6);
	setJa($03A7);
	setJa($03A8);
	setJa($03A9);
	setJa($03B1);
	setJa($03B2);
	setJa($03B3);
	setJa($03B4);
	setJa($03B5);
	setJa($03B6);
	setJa($03B7);
	setJa($03B8);
	setJa($03B9);
	setJa($03BA);
	setJa($03BB);
	setJa($03BC);
	setJa($03BD);
	setJa($03BE);
	setJa($03BF);
	setJa($03C0);
	setJa($03C1);
	setJa($03C3);
	setJa($03C4);
	setJa($03C5);
	setJa($03C6);
	setJa($03C7);
	setJa($03C8);
	setJa($03C9);
	setJa($0410);
	setJa($0411);
	setJa($0412);
	setJa($0413);
	setJa($0414);
	setJa($0415);
	setJa($0401);
	setJa($0416);
	setJa($0417);
	setJa($0418);
	setJa($0419);
	setJa($041A);
	setJa($041B);
	setJa($041C);
	setJa($041D);
	setJa($041E);
	setJa($041F);
	setJa($0420);
	setJa($0421);
	setJa($0422);
	setJa($0423);
	setJa($0424);
	setJa($0425);
	setJa($0426);
	setJa($0427);
	setJa($0428);
	setJa($0429);
	setJa($042A);
	setJa($042B);
	setJa($042C);
	setJa($042D);
	setJa($042E);
	setJa($042F);
	setJa($0430);
	setJa($0431);
	setJa($0432);
	setJa($0433);
	setJa($0434);
	setJa($0435);
	setJa($0451);
	setJa($0436);
	setJa($0437);
	setJa($0438);
	setJa($0439);
	setJa($043A);
	setJa($043B);
	setJa($043C);
	setJa($043D);
	setJa($043E);
	setJa($043F);
	setJa($0440);
	setJa($0441);
	setJa($0442);
	setJa($0443);
	setJa($0444);
	setJa($0445);
	setJa($0446);
	setJa($0447);
	setJa($0448);
	setJa($0449);
	setJa($044A);
	setJa($044B);
	setJa($044C);
	setJa($044D);
	setJa($044E);
	setJa($044F);
	setJa($2500);
	setJa($2502);
	setJa($250C);
	setJa($2510);
	setJa($2518);
	setJa($2514);
	setJa($251C);
	setJa($252C);
	setJa($2524);
	setJa($2534);
	setJa($253C);
	setJa($2501);
	setJa($2503);
	setJa($250F);
	setJa($2513);
	setJa($251B);
	setJa($2517);
	setJa($2523);
	setJa($2533);
	setJa($252B);
	setJa($253B);
	setJa($254B);
	setJa($2520);
	setJa($252F);
	setJa($2528);
	setJa($2537);
	setJa($253F);
	setJa($251D);
	setJa($2530);
	setJa($2525);
	setJa($2538);
	setJa($2542);
	setJa($4E9C);
	setJa($5516);
	setJa($5A03);
	setJa($963F);
	setJa($54C0);
	setJa($611B);
	setJa($6328);
	setJa($59F6);
	setJa($9022);
	setJa($8475);
	setJa($831C);
	setJa($7A50);
	setJa($60AA);
	setJa($63E1);
	setJa($6E25);
	setJa($65ED);
	setJa($8466);
	setJa($82A6);
	setJa($9BF5);
	setJa($6893);
	setJa($5727);
	setJa($65A1);
	setJa($6271);
	setJa($5B9B);
	setJa($59D0);
	setJa($867B);
	setJa($98F4);
	setJa($7D62);
	setJa($7DBE);
	setJa($9B8E);
	setJa($6216);
	setJa($7C9F);
	setJa($88B7);
	setJa($5B89);
	setJa($5EB5);
	setJa($6309);
	setJa($6697);
	setJa($6848);
	setJa($95C7);
	setJa($978D);
	setJa($674F);
	setJa($4EE5);
	setJa($4F0A);
	setJa($4F4D);
	setJa($4F9D);
	setJa($5049);
	setJa($56F2);
	setJa($5937);
	setJa($59D4);
	setJa($5A01);
	setJa($5C09);
	setJa($60DF);
	setJa($610F);
	setJa($6170);
	setJa($6613);
	setJa($6905);
	setJa($70BA);
	setJa($754F);
	setJa($7570);
	setJa($79FB);
	setJa($7DAD);
	setJa($7DEF);
	setJa($80C3);
	setJa($840E);
	setJa($8863);
	setJa($8B02);
	setJa($9055);
	setJa($907A);
	setJa($533B);
	setJa($4E95);
	setJa($4EA5);
	setJa($57DF);
	setJa($80B2);
	setJa($90C1);
	setJa($78EF);
	setJa($4E00);
	setJa($58F1);
	setJa($6EA2);
	setJa($9038);
	setJa($7A32);
	setJa($8328);
	setJa($828B);
	setJa($9C2F);
	setJa($5141);
	setJa($5370);
	setJa($54BD);
	setJa($54E1);
	setJa($56E0);
	setJa($59FB);
	setJa($5F15);
	setJa($98F2);
	setJa($6DEB);
	setJa($80E4);
	setJa($852D);
	setJa($9662);
	setJa($9670);
	setJa($96A0);
	setJa($97FB);
	setJa($540B);
	setJa($53F3);
	setJa($5B87);
	setJa($70CF);
	setJa($7FBD);
	setJa($8FC2);
	setJa($96E8);
	setJa($536F);
	setJa($9D5C);
	setJa($7ABA);
	setJa($4E11);
	setJa($7893);
	setJa($81FC);
	setJa($6E26);
	setJa($5618);
	setJa($5504);
	setJa($6B1D);
	setJa($851A);
	setJa($9C3B);
	setJa($59E5);
	setJa($53A9);
	setJa($6D66);
	setJa($74DC);
	setJa($958F);
	setJa($5642);
	setJa($4E91);
	setJa($904B);
	setJa($96F2);
	setJa($834F);
	setJa($990C);
	setJa($53E1);
	setJa($55B6);
	setJa($5B30);
	setJa($5F71);
	setJa($6620);
	setJa($66F3);
	setJa($6804);
	setJa($6C38);
	setJa($6CF3);
	setJa($6D29);
	setJa($745B);
	setJa($76C8);
	setJa($7A4E);
	setJa($9834);
	setJa($82F1);
	setJa($885B);
	setJa($8A60);
	setJa($92ED);
	setJa($6DB2);
	setJa($75AB);
	setJa($76CA);
	setJa($99C5);
	setJa($60A6);
	setJa($8B01);
	setJa($8D8A);
	setJa($95B2);
	setJa($698E);
	setJa($53AD);
	setJa($5186);
	setJa($5712);
	setJa($5830);
	setJa($5944);
	setJa($5BB4);
	setJa($5EF6);
	setJa($6028);
	setJa($63A9);
	setJa($63F4);
	setJa($6CBF);
	setJa($6F14);
	setJa($708E);
	setJa($7114);
	setJa($7159);
	setJa($71D5);
	setJa($733F);
	setJa($7E01);
	setJa($8276);
	setJa($82D1);
	setJa($8597);
	setJa($9060);
	setJa($925B);
	setJa($9D1B);
	setJa($5869);
	setJa($65BC);
	setJa($6C5A);
	setJa($7525);
	setJa($51F9);
	setJa($592E);
	setJa($5965);
	setJa($5F80);
	setJa($5FDC);
	setJa($62BC);
	setJa($65FA);
	setJa($6A2A);
	setJa($6B27);
	setJa($6BB4);
	setJa($738B);
	setJa($7FC1);
	setJa($8956);
	setJa($9D2C);
	setJa($9D0E);
	setJa($9EC4);
	setJa($5CA1);
	setJa($6C96);
	setJa($837B);
	setJa($5104);
	setJa($5C4B);
	setJa($61B6);
	setJa($81C6);
	setJa($6876);
	setJa($7261);
	setJa($4E59);
	setJa($4FFA);
	setJa($5378);
	setJa($6069);
	setJa($6E29);
	setJa($7A4F);
	setJa($97F3);
	setJa($4E0B);
	setJa($5316);
	setJa($4EEE);
	setJa($4F55);
	setJa($4F3D);
	setJa($4FA1);
	setJa($4F73);
	setJa($52A0);
	setJa($53EF);
	setJa($5609);
	setJa($590F);
	setJa($5AC1);
	setJa($5BB6);
	setJa($5BE1);
	setJa($79D1);
	setJa($6687);
	setJa($679C);
	setJa($67B6);
	setJa($6B4C);
	setJa($6CB3);
	setJa($706B);
	setJa($73C2);
	setJa($798D);
	setJa($79BE);
	setJa($7A3C);
	setJa($7B87);
	setJa($82B1);
	setJa($82DB);
	setJa($8304);
	setJa($8377);
	setJa($83EF);
	setJa($83D3);
	setJa($8766);
	setJa($8AB2);
	setJa($5629);
	setJa($8CA8);
	setJa($8FE6);
	setJa($904E);
	setJa($971E);
	setJa($868A);
	setJa($4FC4);
	setJa($5CE8);
	setJa($6211);
	setJa($7259);
	setJa($753B);
	setJa($81E5);
	setJa($82BD);
	setJa($86FE);
	setJa($8CC0);
	setJa($96C5);
	setJa($9913);
	setJa($99D5);
	setJa($4ECB);
	setJa($4F1A);
	setJa($89E3);
	setJa($56DE);
	setJa($584A);
	setJa($58CA);
	setJa($5EFB);
	setJa($5FEB);
	setJa($602A);
	setJa($6094);
	setJa($6062);
	setJa($61D0);
	setJa($6212);
	setJa($62D0);
	setJa($6539);
	setJa($9B41);
	setJa($6666);
	setJa($68B0);
	setJa($6D77);
	setJa($7070);
	setJa($754C);
	setJa($7686);
	setJa($7D75);
	setJa($82A5);
	setJa($87F9);
	setJa($958B);
	setJa($968E);
	setJa($8C9D);
	setJa($51F1);
	setJa($52BE);
	setJa($5916);
	setJa($54B3);
	setJa($5BB3);
	setJa($5D16);
	setJa($6168);
	setJa($6982);
	setJa($6DAF);
	setJa($788D);
	setJa($84CB);
	setJa($8857);
	setJa($8A72);
	setJa($93A7);
	setJa($9AB8);
	setJa($6D6C);
	setJa($99A8);
	setJa($86D9);
	setJa($57A3);
	setJa($67FF);
	setJa($86CE);
	setJa($920E);
	setJa($5283);
	setJa($5687);
	setJa($5404);
	setJa($5ED3);
	setJa($62E1);
	setJa($64B9);
	setJa($683C);
	setJa($6838);
	setJa($6BBB);
	setJa($7372);
	setJa($78BA);
	setJa($7A6B);
	setJa($899A);
	setJa($89D2);
	setJa($8D6B);
	setJa($8F03);
	setJa($90ED);
	setJa($95A3);
	setJa($9694);
	setJa($9769);
	setJa($5B66);
	setJa($5CB3);
	setJa($697D);
	setJa($984D);
	setJa($984E);
	setJa($639B);
	setJa($7B20);
	setJa($6A2B);
	setJa($6A7F);
	setJa($68B6);
	setJa($9C0D);
	setJa($6F5F);
	setJa($5272);
	setJa($559D);
	setJa($6070);
	setJa($62EC);
	setJa($6D3B);
	setJa($6E07);
	setJa($6ED1);
	setJa($845B);
	setJa($8910);
	setJa($8F44);
	setJa($4E14);
	setJa($9C39);
	setJa($53F6);
	setJa($691B);
	setJa($6A3A);
	setJa($9784);
	setJa($682A);
	setJa($515C);
	setJa($7AC3);
	setJa($84B2);
	setJa($91DC);
	setJa($938C);
	setJa($565B);
	setJa($9D28);
	setJa($6822);
	setJa($8305);
	setJa($8431);
	setJa($7CA5);
	setJa($5208);
	setJa($82C5);
	setJa($74E6);
	setJa($4E7E);
	setJa($4F83);
	setJa($51A0);
	setJa($5BD2);
	setJa($520A);
	setJa($52D8);
	setJa($52E7);
	setJa($5DFB);
	setJa($559A);
	setJa($582A);
	setJa($59E6);
	setJa($5B8C);
	setJa($5B98);
	setJa($5BDB);
	setJa($5E72);
	setJa($5E79);
	setJa($60A3);
	setJa($611F);
	setJa($6163);
	setJa($61BE);
	setJa($63DB);
	setJa($6562);
	setJa($67D1);
	setJa($6853);
	setJa($68FA);
	setJa($6B3E);
	setJa($6B53);
	setJa($6C57);
	setJa($6F22);
	setJa($6F97);
	setJa($6F45);
	setJa($74B0);
	setJa($7518);
	setJa($76E3);
	setJa($770B);
	setJa($7AFF);
	setJa($7BA1);
	setJa($7C21);
	setJa($7DE9);
	setJa($7F36);
	setJa($7FF0);
	setJa($809D);
	setJa($8266);
	setJa($839E);
	setJa($89B3);
	setJa($8ACC);
	setJa($8CAB);
	setJa($9084);
	setJa($9451);
	setJa($9593);
	setJa($9591);
	setJa($95A2);
	setJa($9665);
	setJa($97D3);
	setJa($9928);
	setJa($8218);
	setJa($4E38);
	setJa($542B);
	setJa($5CB8);
	setJa($5DCC);
	setJa($73A9);
	setJa($764C);
	setJa($773C);
	setJa($5CA9);
	setJa($7FEB);
	setJa($8D0B);
	setJa($96C1);
	setJa($9811);
	setJa($9854);
	setJa($9858);
	setJa($4F01);
	setJa($4F0E);
	setJa($5371);
	setJa($559C);
	setJa($5668);
	setJa($57FA);
	setJa($5947);
	setJa($5B09);
	setJa($5BC4);
	setJa($5C90);
	setJa($5E0C);
	setJa($5E7E);
	setJa($5FCC);
	setJa($63EE);
	setJa($673A);
	setJa($65D7);
	setJa($65E2);
	setJa($671F);
	setJa($68CB);
	setJa($68C4);
	setJa($6A5F);
	setJa($5E30);
	setJa($6BC5);
	setJa($6C17);
	setJa($6C7D);
	setJa($757F);
	setJa($7948);
	setJa($5B63);
	setJa($7A00);
	setJa($7D00);
	setJa($5FBD);
	setJa($898F);
	setJa($8A18);
	setJa($8CB4);
	setJa($8D77);
	setJa($8ECC);
	setJa($8F1D);
	setJa($98E2);
	setJa($9A0E);
	setJa($9B3C);
	setJa($4E80);
	setJa($507D);
	setJa($5100);
	setJa($5993);
	setJa($5B9C);
	setJa($622F);
	setJa($6280);
	setJa($64EC);
	setJa($6B3A);
	setJa($72A0);
	setJa($7591);
	setJa($7947);
	setJa($7FA9);
	setJa($87FB);
	setJa($8ABC);
	setJa($8B70);
	setJa($63AC);
	setJa($83CA);
	setJa($97A0);
	setJa($5409);
	setJa($5403);
	setJa($55AB);
	setJa($6854);
	setJa($6A58);
	setJa($8A70);
	setJa($7827);
	setJa($6775);
	setJa($9ECD);
	setJa($5374);
	setJa($5BA2);
	setJa($811A);
	setJa($8650);
	setJa($9006);
	setJa($4E18);
	setJa($4E45);
	setJa($4EC7);
	setJa($4F11);
	setJa($53CA);
	setJa($5438);
	setJa($5BAE);
	setJa($5F13);
	setJa($6025);
	setJa($6551);
	setJa($673D);
	setJa($6C42);
	setJa($6C72);
	setJa($6CE3);
	setJa($7078);
	setJa($7403);
	setJa($7A76);
	setJa($7AAE);
	setJa($7B08);
	setJa($7D1A);
	setJa($7CFE);
	setJa($7D66);
	setJa($65E7);
	setJa($725B);
	setJa($53BB);
	setJa($5C45);
	setJa($5DE8);
	setJa($62D2);
	setJa($62E0);
	setJa($6319);
	setJa($6E20);
	setJa($865A);
	setJa($8A31);
	setJa($8DDD);
	setJa($92F8);
	setJa($6F01);
	setJa($79A6);
	setJa($9B5A);
	setJa($4EA8);
	setJa($4EAB);
	setJa($4EAC);
	setJa($4F9B);
	setJa($4FA0);
	setJa($50D1);
	setJa($5147);
	setJa($7AF6);
	setJa($5171);
	setJa($51F6);
	setJa($5354);
	setJa($5321);
	setJa($537F);
	setJa($53EB);
	setJa($55AC);
	setJa($5883);
	setJa($5CE1);
	setJa($5F37);
	setJa($5F4A);
	setJa($602F);
	setJa($6050);
	setJa($606D);
	setJa($631F);
	setJa($6559);
	setJa($6A4B);
	setJa($6CC1);
	setJa($72C2);
	setJa($72ED);
	setJa($77EF);
	setJa($80F8);
	setJa($8105);
	setJa($8208);
	setJa($854E);
	setJa($90F7);
	setJa($93E1);
	setJa($97FF);
	setJa($9957);
	setJa($9A5A);
	setJa($4EF0);
	setJa($51DD);
	setJa($5C2D);
	setJa($6681);
	setJa($696D);
	setJa($5C40);
	setJa($66F2);
	setJa($6975);
	setJa($7389);
	setJa($6850);
	setJa($7C81);
	setJa($50C5);
	setJa($52E4);
	setJa($5747);
	setJa($5DFE);
	setJa($9326);
	setJa($65A4);
	setJa($6B23);
	setJa($6B3D);
	setJa($7434);
	setJa($7981);
	setJa($79BD);
	setJa($7B4B);
	setJa($7DCA);
	setJa($82B9);
	setJa($83CC);
	setJa($887F);
	setJa($895F);
	setJa($8B39);
	setJa($8FD1);
	setJa($91D1);
	setJa($541F);
	setJa($9280);
	setJa($4E5D);
	setJa($5036);
	setJa($53E5);
	setJa($533A);
	setJa($72D7);
	setJa($7396);
	setJa($77E9);
	setJa($82E6);
	setJa($8EAF);
	setJa($99C6);
	setJa($99C8);
	setJa($99D2);
	setJa($5177);
	setJa($611A);
	setJa($865E);
	setJa($55B0);
	setJa($7A7A);
	setJa($5076);
	setJa($5BD3);
	setJa($9047);
	setJa($9685);
	setJa($4E32);
	setJa($6ADB);
	setJa($91E7);
	setJa($5C51);
	setJa($5C48);
	setJa($6398);
	setJa($7A9F);
	setJa($6C93);
	setJa($9774);
	setJa($8F61);
	setJa($7AAA);
	setJa($718A);
	setJa($9688);
	setJa($7C82);
	setJa($6817);
	setJa($7E70);
	setJa($6851);
	setJa($936C);
	setJa($52F2);
	setJa($541B);
	setJa($85AB);
	setJa($8A13);
	setJa($7FA4);
	setJa($8ECD);
	setJa($90E1);
	setJa($5366);
	setJa($8888);
	setJa($7941);
	setJa($4FC2);
	setJa($50BE);
	setJa($5211);
	setJa($5144);
	setJa($5553);
	setJa($572D);
	setJa($73EA);
	setJa($578B);
	setJa($5951);
	setJa($5F62);
	setJa($5F84);
	setJa($6075);
	setJa($6176);
	setJa($6167);
	setJa($61A9);
	setJa($63B2);
	setJa($643A);
	setJa($656C);
	setJa($666F);
	setJa($6842);
	setJa($6E13);
	setJa($7566);
	setJa($7A3D);
	setJa($7CFB);
	setJa($7D4C);
	setJa($7D99);
	setJa($7E4B);
	setJa($7F6B);
	setJa($830E);
	setJa($834A);
	setJa($86CD);
	setJa($8A08);
	setJa($8A63);
	setJa($8B66);
	setJa($8EFD);
	setJa($981A);
	setJa($9D8F);
	setJa($82B8);
	setJa($8FCE);
	setJa($9BE8);
	setJa($5287);
	setJa($621F);
	setJa($6483);
	setJa($6FC0);
	setJa($9699);
	setJa($6841);
	setJa($5091);
	setJa($6B20);
	setJa($6C7A);
	setJa($6F54);
	setJa($7A74);
	setJa($7D50);
	setJa($8840);
	setJa($8A23);
	setJa($6708);
	setJa($4EF6);
	setJa($5039);
	setJa($5026);
	setJa($5065);
	setJa($517C);
	setJa($5238);
	setJa($5263);
	setJa($55A7);
	setJa($570F);
	setJa($5805);
	setJa($5ACC);
	setJa($5EFA);
	setJa($61B2);
	setJa($61F8);
	setJa($62F3);
	setJa($6372);
	setJa($691C);
	setJa($6A29);
	setJa($727D);
	setJa($72AC);
	setJa($732E);
	setJa($7814);
	setJa($786F);
	setJa($7D79);
	setJa($770C);
	setJa($80A9);
	setJa($898B);
	setJa($8B19);
	setJa($8CE2);
	setJa($8ED2);
	setJa($9063);
	setJa($9375);
	setJa($967A);
	setJa($9855);
	setJa($9A13);
	setJa($9E78);
	setJa($5143);
	setJa($539F);
	setJa($53B3);
	setJa($5E7B);
	setJa($5F26);
	setJa($6E1B);
	setJa($6E90);
	setJa($7384);
	setJa($73FE);
	setJa($7D43);
	setJa($8237);
	setJa($8A00);
	setJa($8AFA);
	setJa($9650);
	setJa($4E4E);
	setJa($500B);
	setJa($53E4);
	setJa($547C);
	setJa($56FA);
	setJa($59D1);
	setJa($5B64);
	setJa($5DF1);
	setJa($5EAB);
	setJa($5F27);
	setJa($6238);
	setJa($6545);
	setJa($67AF);
	setJa($6E56);
	setJa($72D0);
	setJa($7CCA);
	setJa($88B4);
	setJa($80A1);
	setJa($80E1);
	setJa($83F0);
	setJa($864E);
	setJa($8A87);
	setJa($8DE8);
	setJa($9237);
	setJa($96C7);
	setJa($9867);
	setJa($9F13);
	setJa($4E94);
	setJa($4E92);
	setJa($4F0D);
	setJa($5348);
	setJa($5449);
	setJa($543E);
	setJa($5A2F);
	setJa($5F8C);
	setJa($5FA1);
	setJa($609F);
	setJa($68A7);
	setJa($6A8E);
	setJa($745A);
	setJa($7881);
	setJa($8A9E);
	setJa($8AA4);
	setJa($8B77);
	setJa($9190);
	setJa($4E5E);
	setJa($9BC9);
	setJa($4EA4);
	setJa($4F7C);
	setJa($4FAF);
	setJa($5019);
	setJa($5016);
	setJa($5149);
	setJa($516C);
	setJa($529F);
	setJa($52B9);
	setJa($52FE);
	setJa($539A);
	setJa($53E3);
	setJa($5411);
	setJa($540E);
	setJa($5589);
	setJa($5751);
	setJa($57A2);
	setJa($597D);
	setJa($5B54);
	setJa($5B5D);
	setJa($5B8F);
	setJa($5DE5);
	setJa($5DE7);
	setJa($5DF7);
	setJa($5E78);
	setJa($5E83);
	setJa($5E9A);
	setJa($5EB7);
	setJa($5F18);
	setJa($6052);
	setJa($614C);
	setJa($6297);
	setJa($62D8);
	setJa($63A7);
	setJa($653B);
	setJa($6602);
	setJa($6643);
	setJa($66F4);
	setJa($676D);
	setJa($6821);
	setJa($6897);
	setJa($69CB);
	setJa($6C5F);
	setJa($6D2A);
	setJa($6D69);
	setJa($6E2F);
	setJa($6E9D);
	setJa($7532);
	setJa($7687);
	setJa($786C);
	setJa($7A3F);
	setJa($7CE0);
	setJa($7D05);
	setJa($7D18);
	setJa($7D5E);
	setJa($7DB1);
	setJa($8015);
	setJa($8003);
	setJa($80AF);
	setJa($80B1);
	setJa($8154);
	setJa($818F);
	setJa($822A);
	setJa($8352);
	setJa($884C);
	setJa($8861);
	setJa($8B1B);
	setJa($8CA2);
	setJa($8CFC);
	setJa($90CA);
	setJa($9175);
	setJa($9271);
	setJa($783F);
	setJa($92FC);
	setJa($95A4);
	setJa($964D);
	setJa($9805);
	setJa($9999);
	setJa($9AD8);
	setJa($9D3B);
	setJa($525B);
	setJa($52AB);
	setJa($53F7);
	setJa($5408);
	setJa($58D5);
	setJa($62F7);
	setJa($6FE0);
	setJa($8C6A);
	setJa($8F5F);
	setJa($9EB9);
	setJa($514B);
	setJa($523B);
	setJa($544A);
	setJa($56FD);
	setJa($7A40);
	setJa($9177);
	setJa($9D60);
	setJa($9ED2);
	setJa($7344);
	setJa($6F09);
	setJa($8170);
	setJa($7511);
	setJa($5FFD);
	setJa($60DA);
	setJa($9AA8);
	setJa($72DB);
	setJa($8FBC);
	setJa($6B64);
	setJa($9803);
	setJa($4ECA);
	setJa($56F0);
	setJa($5764);
	setJa($58BE);
	setJa($5A5A);
	setJa($6068);
	setJa($61C7);
	setJa($660F);
	setJa($6606);
	setJa($6839);
	setJa($68B1);
	setJa($6DF7);
	setJa($75D5);
	setJa($7D3A);
	setJa($826E);
	setJa($9B42);
	setJa($4E9B);
	setJa($4F50);
	setJa($53C9);
	setJa($5506);
	setJa($5D6F);
	setJa($5DE6);
	setJa($5DEE);
	setJa($67FB);
	setJa($6C99);
	setJa($7473);
	setJa($7802);
	setJa($8A50);
	setJa($9396);
	setJa($88DF);
	setJa($5750);
	setJa($5EA7);
	setJa($632B);
	setJa($50B5);
	setJa($50AC);
	setJa($518D);
	setJa($6700);
	setJa($54C9);
	setJa($585E);
	setJa($59BB);
	setJa($5BB0);
	setJa($5F69);
	setJa($624D);
	setJa($63A1);
	setJa($683D);
	setJa($6B73);
	setJa($6E08);
	setJa($707D);
	setJa($91C7);
	setJa($7280);
	setJa($7815);
	setJa($7826);
	setJa($796D);
	setJa($658E);
	setJa($7D30);
	setJa($83DC);
	setJa($88C1);
	setJa($8F09);
	setJa($969B);
	setJa($5264);
	setJa($5728);
	setJa($6750);
	setJa($7F6A);
	setJa($8CA1);
	setJa($51B4);
	setJa($5742);
	setJa($962A);
	setJa($583A);
	setJa($698A);
	setJa($80B4);
	setJa($54B2);
	setJa($5D0E);
	setJa($57FC);
	setJa($7895);
	setJa($9DFA);
	setJa($4F5C);
	setJa($524A);
	setJa($548B);
	setJa($643E);
	setJa($6628);
	setJa($6714);
	setJa($67F5);
	setJa($7A84);
	setJa($7B56);
	setJa($7D22);
	setJa($932F);
	setJa($685C);
	setJa($9BAD);
	setJa($7B39);
	setJa($5319);
	setJa($518A);
	setJa($5237);
	setJa($5BDF);
	setJa($62F6);
	setJa($64AE);
	setJa($64E6);
	setJa($672D);
	setJa($6BBA);
	setJa($85A9);
	setJa($96D1);
	setJa($7690);
	setJa($9BD6);
	setJa($634C);
	setJa($9306);
	setJa($9BAB);
	setJa($76BF);
	setJa($6652);
	setJa($4E09);
	setJa($5098);
	setJa($53C2);
	setJa($5C71);
	setJa($60E8);
	setJa($6492);
	setJa($6563);
	setJa($685F);
	setJa($71E6);
	setJa($73CA);
	setJa($7523);
	setJa($7B97);
	setJa($7E82);
	setJa($8695);
	setJa($8B83);
	setJa($8CDB);
	setJa($9178);
	setJa($9910);
	setJa($65AC);
	setJa($66AB);
	setJa($6B8B);
	setJa($4ED5);
	setJa($4ED4);
	setJa($4F3A);
	setJa($4F7F);
	setJa($523A);
	setJa($53F8);
	setJa($53F2);
	setJa($55E3);
	setJa($56DB);
	setJa($58EB);
	setJa($59CB);
	setJa($59C9);
	setJa($59FF);
	setJa($5B50);
	setJa($5C4D);
	setJa($5E02);
	setJa($5E2B);
	setJa($5FD7);
	setJa($601D);
	setJa($6307);
	setJa($652F);
	setJa($5B5C);
	setJa($65AF);
	setJa($65BD);
	setJa($65E8);
	setJa($679D);
	setJa($6B62);
	setJa($6B7B);
	setJa($6C0F);
	setJa($7345);
	setJa($7949);
	setJa($79C1);
	setJa($7CF8);
	setJa($7D19);
	setJa($7D2B);
	setJa($80A2);
	setJa($8102);
	setJa($81F3);
	setJa($8996);
	setJa($8A5E);
	setJa($8A69);
	setJa($8A66);
	setJa($8A8C);
	setJa($8AEE);
	setJa($8CC7);
	setJa($8CDC);
	setJa($96CC);
	setJa($98FC);
	setJa($6B6F);
	setJa($4E8B);
	setJa($4F3C);
	setJa($4F8D);
	setJa($5150);
	setJa($5B57);
	setJa($5BFA);
	setJa($6148);
	setJa($6301);
	setJa($6642);
	setJa($6B21);
	setJa($6ECB);
	setJa($6CBB);
	setJa($723E);
	setJa($74BD);
	setJa($75D4);
	setJa($78C1);
	setJa($793A);
	setJa($800C);
	setJa($8033);
	setJa($81EA);
	setJa($8494);
	setJa($8F9E);
	setJa($6C50);
	setJa($9E7F);
	setJa($5F0F);
	setJa($8B58);
	setJa($9D2B);
	setJa($7AFA);
	setJa($8EF8);
	setJa($5B8D);
	setJa($96EB);
	setJa($4E03);
	setJa($53F1);
	setJa($57F7);
	setJa($5931);
	setJa($5AC9);
	setJa($5BA4);
	setJa($6089);
	setJa($6E7F);
	setJa($6F06);
	setJa($75BE);
	setJa($8CEA);
	setJa($5B9F);
	setJa($8500);
	setJa($7BE0);
	setJa($5072);
	setJa($67F4);
	setJa($829D);
	setJa($5C61);
	setJa($854A);
	setJa($7E1E);
	setJa($820E);
	setJa($5199);
	setJa($5C04);
	setJa($6368);
	setJa($8D66);
	setJa($659C);
	setJa($716E);
	setJa($793E);
	setJa($7D17);
	setJa($8005);
	setJa($8B1D);
	setJa($8ECA);
	setJa($906E);
	setJa($86C7);
	setJa($90AA);
	setJa($501F);
	setJa($52FA);
	setJa($5C3A);
	setJa($6753);
	setJa($707C);
	setJa($7235);
	setJa($914C);
	setJa($91C8);
	setJa($932B);
	setJa($82E5);
	setJa($5BC2);
	setJa($5F31);
	setJa($60F9);
	setJa($4E3B);
	setJa($53D6);
	setJa($5B88);
	setJa($624B);
	setJa($6731);
	setJa($6B8A);
	setJa($72E9);
	setJa($73E0);
	setJa($7A2E);
	setJa($816B);
	setJa($8DA3);
	setJa($9152);
	setJa($9996);
	setJa($5112);
	setJa($53D7);
	setJa($546A);
	setJa($5BFF);
	setJa($6388);
	setJa($6A39);
	setJa($7DAC);
	setJa($9700);
	setJa($56DA);
	setJa($53CE);
	setJa($5468);
	setJa($5B97);

	setJa($5C31);
	setJa($5DDE);
	setJa($4FEE);
	setJa($6101);
	setJa($62FE);
	setJa($6D32);
	setJa($79C0);
	setJa($79CB);
	setJa($7D42);
	setJa($7E4D);
	setJa($7FD2);
	setJa($81ED);
	setJa($821F);
	setJa($8490);
	setJa($8846);
	setJa($8972);
	setJa($8B90);
	setJa($8E74);
	setJa($8F2F);
	setJa($9031);
	setJa($914B);
	setJa($916C);
	setJa($96C6);
	setJa($919C);
	setJa($4EC0);
	setJa($4F4F);
	setJa($5145);
	setJa($5341);
	setJa($5F93);
	setJa($620E);
	setJa($67D4);
	setJa($6C41);
	setJa($6E0B);
	setJa($7363);
	setJa($7E26);
	setJa($91CD);
	setJa($9283);
	setJa($53D4);
	setJa($5919);
	setJa($5BBF);
	setJa($6DD1);
	setJa($795D);
	setJa($7E2E);
	setJa($7C9B);
	setJa($587E);
	setJa($719F);
	setJa($51FA);
	setJa($8853);
	setJa($8FF0);
	setJa($4FCA);
	setJa($5CFB);
	setJa($6625);
	setJa($77AC);
	setJa($7AE3);
	setJa($821C);
	setJa($99FF);
	setJa($51C6);
	setJa($5FAA);
	setJa($65EC);
	setJa($696F);
	setJa($6B89);
	setJa($6DF3);
	setJa($6E96);
	setJa($6F64);
	setJa($76FE);
	setJa($7D14);
	setJa($5DE1);
	setJa($9075);
	setJa($9187);
	setJa($9806);
	setJa($51E6);
	setJa($521D);
	setJa($6240);
	setJa($6691);
	setJa($66D9);
	setJa($6E1A);
	setJa($5EB6);
	setJa($7DD2);
	setJa($7F72);
	setJa($66F8);
	setJa($85AF);
	setJa($85F7);
	setJa($8AF8);
	setJa($52A9);
	setJa($53D9);
	setJa($5973);
	setJa($5E8F);
	setJa($5F90);
	setJa($6055);
	setJa($92E4);
	setJa($9664);
	setJa($50B7);
	setJa($511F);
	setJa($52DD);
	setJa($5320);
	setJa($5347);
	setJa($53EC);
	setJa($54E8);
	setJa($5546);
	setJa($5531);
	setJa($5617);
	setJa($5968);
	setJa($59BE);
	setJa($5A3C);
	setJa($5BB5);
	setJa($5C06);
	setJa($5C0F);
	setJa($5C11);
	setJa($5C1A);
	setJa($5E84);
	setJa($5E8A);
	setJa($5EE0);
	setJa($5F70);
	setJa($627F);
	setJa($6284);
	setJa($62DB);
	setJa($638C);
	setJa($6377);
	setJa($6607);
	setJa($660C);
	setJa($662D);
	setJa($6676);
	setJa($677E);
	setJa($68A2);
	setJa($6A1F);
	setJa($6A35);
	setJa($6CBC);
	setJa($6D88);
	setJa($6E09);
	setJa($6E58);
	setJa($713C);
	setJa($7126);
	setJa($7167);
	setJa($75C7);
	setJa($7701);
	setJa($785D);
	setJa($7901);
	setJa($7965);
	setJa($79F0);
	setJa($7AE0);
	setJa($7B11);
	setJa($7CA7);
	setJa($7D39);
	setJa($8096);
	setJa($83D6);
	setJa($848B);
	setJa($8549);
	setJa($885D);
	setJa($88F3);
	setJa($8A1F);
	setJa($8A3C);
	setJa($8A54);
	setJa($8A73);
	setJa($8C61);
	setJa($8CDE);
	setJa($91A4);
	setJa($9266);
	setJa($937E);
	setJa($9418);
	setJa($969C);
	setJa($9798);
	setJa($4E0A);
	setJa($4E08);
	setJa($4E1E);
	setJa($4E57);
	setJa($5197);
	setJa($5270);
	setJa($57CE);
	setJa($5834);
	setJa($58CC);
	setJa($5B22);
	setJa($5E38);
	setJa($60C5);
	setJa($64FE);
	setJa($6761);
	setJa($6756);
	setJa($6D44);
	setJa($72B6);
	setJa($7573);
	setJa($7A63);
	setJa($84B8);
	setJa($8B72);
	setJa($91B8);
	setJa($9320);
	setJa($5631);
	setJa($57F4);
	setJa($98FE);
	setJa($62ED);
	setJa($690D);
	setJa($6B96);
	setJa($71ED);
	setJa($7E54);
	setJa($8077);
	setJa($8272);
	setJa($89E6);
	setJa($98DF);
	setJa($8755);
	setJa($8FB1);
	setJa($5C3B);
	setJa($4F38);
	setJa($4FE1);
	setJa($4FB5);
	setJa($5507);
	setJa($5A20);
	setJa($5BDD);
	setJa($5BE9);
	setJa($5FC3);
	setJa($614E);
	setJa($632F);
	setJa($65B0);
	setJa($664B);
	setJa($68EE);
	setJa($699B);
	setJa($6D78);
	setJa($6DF1);
	setJa($7533);
	setJa($75B9);
	setJa($771F);
	setJa($795E);
	setJa($79E6);
	setJa($7D33);
	setJa($81E3);
	setJa($82AF);
	setJa($85AA);
	setJa($89AA);
	setJa($8A3A);
	setJa($8EAB);
	setJa($8F9B);
	setJa($9032);
	setJa($91DD);
	setJa($9707);
	setJa($4EBA);
	setJa($4EC1);
	setJa($5203);
	setJa($5875);
	setJa($58EC);
	setJa($5C0B);
	setJa($751A);
	setJa($5C3D);
	setJa($814E);
	setJa($8A0A);
	setJa($8FC5);
	setJa($9663);
	setJa($976D);
	setJa($7B25);
	setJa($8ACF);
	setJa($9808);
	setJa($9162);
	setJa($56F3);
	setJa($53A8);
	setJa($9017);
	setJa($5439);
	setJa($5782);
	setJa($5E25);
	setJa($63A8);
	setJa($6C34);
	setJa($708A);
	setJa($7761);
	setJa($7C8B);
	setJa($7FE0);
	setJa($8870);
	setJa($9042);
	setJa($9154);
	setJa($9310);
	setJa($9318);
	setJa($968F);
	setJa($745E);
	setJa($9AC4);
	setJa($5D07);
	setJa($5D69);
	setJa($6570);
	setJa($67A2);
	setJa($8DA8);
	setJa($96DB);
	setJa($636E);
	setJa($6749);
	setJa($6919);
	setJa($83C5);
	setJa($9817);
	setJa($96C0);
	setJa($88FE);
	setJa($6F84);
	setJa($647A);
	setJa($5BF8);
	setJa($4E16);
	setJa($702C);
	setJa($755D);
	setJa($662F);
	setJa($51C4);
	setJa($5236);
	setJa($52E2);
	setJa($59D3);
	setJa($5F81);
	setJa($6027);
	setJa($6210);
	setJa($653F);
	setJa($6574);
	setJa($661F);
	setJa($6674);
	setJa($68F2);
	setJa($6816);
	setJa($6B63);
	setJa($6E05);
	setJa($7272);
	setJa($751F);
	setJa($76DB);
	setJa($7CBE);
	setJa($8056);
	setJa($58F0);
	setJa($88FD);
	setJa($897F);
	setJa($8AA0);
	setJa($8A93);
	setJa($8ACB);
	setJa($901D);
	setJa($9192);
	setJa($9752);
	setJa($9759);
	setJa($6589);
	setJa($7A0E);
	setJa($8106);
	setJa($96BB);
	setJa($5E2D);
	setJa($60DC);
	setJa($621A);
	setJa($65A5);
	setJa($6614);
	setJa($6790);
	setJa($77F3);
	setJa($7A4D);
	setJa($7C4D);
	setJa($7E3E);
	setJa($810A);
	setJa($8CAC);
	setJa($8D64);
	setJa($8DE1);
	setJa($8E5F);
	setJa($78A9);
	setJa($5207);
	setJa($62D9);
	setJa($63A5);
	setJa($6442);
	setJa($6298);
	setJa($8A2D);
	setJa($7A83);
	setJa($7BC0);
	setJa($8AAC);
	setJa($96EA);
	setJa($7D76);
	setJa($820C);
	setJa($8749);
	setJa($4ED9);
	setJa($5148);
	setJa($5343);
	setJa($5360);
	setJa($5BA3);
	setJa($5C02);
	setJa($5C16);
	setJa($5DDD);
	setJa($6226);
	setJa($6247);
	setJa($64B0);
	setJa($6813);
	setJa($6834);
	setJa($6CC9);
	setJa($6D45);
	setJa($6D17);
	setJa($67D3);
	setJa($6F5C);
	setJa($714E);
	setJa($717D);
	setJa($65CB);
	setJa($7A7F);
	setJa($7BAD);
	setJa($7DDA);
	setJa($7E4A);
	setJa($7FA8);
	setJa($817A);
	setJa($821B);
	setJa($8239);
	setJa($85A6);
	setJa($8A6E);
	setJa($8CCE);
	setJa($8DF5);
	setJa($9078);
	setJa($9077);
	setJa($92AD);
	setJa($9291);
	setJa($9583);
	setJa($9BAE);
	setJa($524D);
	setJa($5584);
	setJa($6F38);
	setJa($7136);
	setJa($5168);
	setJa($7985);
	setJa($7E55);
	setJa($81B3);
	setJa($7CCE);
	setJa($564C);
	setJa($5851);
	setJa($5CA8);
	setJa($63AA);
	setJa($66FE);
	setJa($66FD);
	setJa($695A);
	setJa($72D9);
	setJa($758F);
	setJa($758E);
	setJa($790E);
	setJa($7956);
	setJa($79DF);
	setJa($7C97);
	setJa($7D20);
	setJa($7D44);
	setJa($8607);
	setJa($8A34);
	setJa($963B);
	setJa($9061);
	setJa($9F20);
	setJa($50E7);
	setJa($5275);
	setJa($53CC);
	setJa($53E2);
	setJa($5009);
	setJa($55AA);
	setJa($58EE);
	setJa($594F);
	setJa($723D);
	setJa($5B8B);
	setJa($5C64);
	setJa($531D);
	setJa($60E3);
	setJa($60F3);
	setJa($635C);
	setJa($6383);
	setJa($633F);
	setJa($63BB);
	setJa($64CD);
	setJa($65E9);
	setJa($66F9);
	setJa($5DE3);
	setJa($69CD);
	setJa($69FD);
	setJa($6F15);
	setJa($71E5);
	setJa($4E89);
	setJa($75E9);
	setJa($76F8);
	setJa($7A93);
	setJa($7CDF);
	setJa($7DCF);
	setJa($7D9C);
	setJa($8061);
	setJa($8349);
	setJa($8358);
	setJa($846C);
	setJa($84BC);
	setJa($85FB);
	setJa($88C5);
	setJa($8D70);
	setJa($9001);
	setJa($906D);
	setJa($9397);
	setJa($971C);
	setJa($9A12);
	setJa($50CF);
	setJa($5897);
	setJa($618E);
	setJa($81D3);
	setJa($8535);
	setJa($8D08);
	setJa($9020);
	setJa($4FC3);
	setJa($5074);
	setJa($5247);
	setJa($5373);
	setJa($606F);
	setJa($6349);
	setJa($675F);
	setJa($6E2C);
	setJa($8DB3);
	setJa($901F);
	setJa($4FD7);
	setJa($5C5E);
	setJa($8CCA);
	setJa($65CF);
	setJa($7D9A);
	setJa($5352);
	setJa($8896);
	setJa($5176);
	setJa($63C3);
	setJa($5B58);
	setJa($5B6B);
	setJa($5C0A);
	setJa($640D);
	setJa($6751);
	setJa($905C);
	setJa($4ED6);
	setJa($591A);
	setJa($592A);
	setJa($6C70);
	setJa($8A51);
	setJa($553E);
	setJa($5815);
	setJa($59A5);
	setJa($60F0);
	setJa($6253);
	setJa($67C1);
	setJa($8235);
	setJa($6955);
	setJa($9640);
	setJa($99C4);
	setJa($9A28);
	setJa($4F53);
	setJa($5806);
	setJa($5BFE);
	setJa($8010);
	setJa($5CB1);
	setJa($5E2F);
	setJa($5F85);
	setJa($6020);
	setJa($614B);
	setJa($6234);
	setJa($66FF);
	setJa($6CF0);
	setJa($6EDE);
	setJa($80CE);
	setJa($817F);
	setJa($82D4);
	setJa($888B);
	setJa($8CB8);
	setJa($9000);
	setJa($902E);
	setJa($968A);
	setJa($9EDB);
	setJa($9BDB);
	setJa($4EE3);
	setJa($53F0);
	setJa($5927);
	setJa($7B2C);
	setJa($918D);
	setJa($984C);
	setJa($9DF9);
	setJa($6EDD);
	setJa($7027);
	setJa($5353);
	setJa($5544);
	setJa($5B85);
	setJa($6258);
	setJa($629E);
	setJa($62D3);
	setJa($6CA2);
	setJa($6FEF);
	setJa($7422);
	setJa($8A17);
	setJa($9438);
	setJa($6FC1);
	setJa($8AFE);
	setJa($8338);
	setJa($51E7);
	setJa($86F8);
	setJa($53EA);
	setJa($53E9);
	setJa($4F46);
	setJa($9054);
	setJa($8FB0);
	setJa($596A);
	setJa($8131);
	setJa($5DFD);
	setJa($7AEA);
	setJa($8FBF);
	setJa($68DA);
	setJa($8C37);
	setJa($72F8);
	setJa($9C48);
	setJa($6A3D);
	setJa($8AB0);
	setJa($4E39);
	setJa($5358);
	setJa($5606);
	setJa($5766);
	setJa($62C5);
	setJa($63A2);
	setJa($65E6);
	setJa($6B4E);
	setJa($6DE1);
	setJa($6E5B);
	setJa($70AD);
	setJa($77ED);
	setJa($7AEF);
	setJa($7BAA);
	setJa($7DBB);
	setJa($803D);
	setJa($80C6);
	setJa($86CB);
	setJa($8A95);
	setJa($935B);
	setJa($56E3);
	setJa($58C7);
	setJa($5F3E);
	setJa($65AD);
	setJa($6696);
	setJa($6A80);
	setJa($6BB5);
	setJa($7537);
	setJa($8AC7);
	setJa($5024);
	setJa($77E5);
	setJa($5730);
	setJa($5F1B);
	setJa($6065);
	setJa($667A);
	setJa($6C60);
	setJa($75F4);
	setJa($7A1A);
	setJa($7F6E);
	setJa($81F4);
	setJa($8718);
	setJa($9045);
	setJa($99B3);
	setJa($7BC9);
	setJa($755C);
	setJa($7AF9);
	setJa($7B51);
	setJa($84C4);
	setJa($9010);
	setJa($79E9);
	setJa($7A92);
	setJa($8336);
	setJa($5AE1);
	setJa($7740);
	setJa($4E2D);
	setJa($4EF2);
	setJa($5B99);
	setJa($5FE0);
	setJa($62BD);
	setJa($663C);
	setJa($67F1);
	setJa($6CE8);
	setJa($866B);
	setJa($8877);
	setJa($8A3B);
	setJa($914E);
	setJa($92F3);
	setJa($99D0);
	setJa($6A17);
	setJa($7026);
	setJa($732A);
	setJa($82E7);
	setJa($8457);
	setJa($8CAF);
	setJa($4E01);
	setJa($5146);
	setJa($51CB);
	setJa($558B);
	setJa($5BF5);
	setJa($5E16);
	setJa($5E33);
	setJa($5E81);
	setJa($5F14);
	setJa($5F35);
	setJa($5F6B);
	setJa($5FB4);
	setJa($61F2);
	setJa($6311);
	setJa($66A2);
	setJa($671D);
	setJa($6F6E);
	setJa($7252);
	setJa($753A);
	setJa($773A);
	setJa($8074);
	setJa($8139);
	setJa($8178);
	setJa($8776);
	setJa($8ABF);
	setJa($8ADC);
	setJa($8D85);
	setJa($8DF3);
	setJa($929A);
	setJa($9577);
	setJa($9802);
	setJa($9CE5);
	setJa($52C5);
	setJa($6357);
	setJa($76F4);
	setJa($6715);
	setJa($6C88);
	setJa($73CD);
	setJa($8CC3);
	setJa($93AE);
	setJa($9673);
	setJa($6D25);
	setJa($589C);
	setJa($690E);
	setJa($69CC);
	setJa($8FFD);
	setJa($939A);
	setJa($75DB);
	setJa($901A);
	setJa($585A);
	setJa($6802);
	setJa($63B4);
	setJa($69FB);
	setJa($4F43);
	setJa($6F2C);
	setJa($67D8);
	setJa($8FBB);
	setJa($8526);
	setJa($7DB4);
	setJa($9354);
	setJa($693F);
	setJa($6F70);
	setJa($576A);
	setJa($58F7);
	setJa($5B2C);
	setJa($7D2C);
	setJa($722A);
	setJa($540A);
	setJa($91E3);
	setJa($9DB4);
	setJa($4EAD);
	setJa($4F4E);
	setJa($505C);
	setJa($5075);
	setJa($5243);
	setJa($8C9E);
	setJa($5448);
	setJa($5824);
	setJa($5B9A);
	setJa($5E1D);
	setJa($5E95);
	setJa($5EAD);
	setJa($5EF7);
	setJa($5F1F);
	setJa($608C);
	setJa($62B5);
	setJa($633A);
	setJa($63D0);
	setJa($68AF);
	setJa($6C40);
	setJa($7887);
	setJa($798E);
	setJa($7A0B);
	setJa($7DE0);
	setJa($8247);
	setJa($8A02);
	setJa($8AE6);
	setJa($8E44);
	setJa($9013);
	setJa($90B8);
	setJa($912D);
	setJa($91D8);
	setJa($9F0E);
	setJa($6CE5);
	setJa($6458);
	setJa($64E2);
	setJa($6575);
	setJa($6EF4);
	setJa($7684);
	setJa($7B1B);
	setJa($9069);
	setJa($93D1);
	setJa($6EBA);
	setJa($54F2);
	setJa($5FB9);
	setJa($64A4);
	setJa($8F4D);
	setJa($8FED);
	setJa($9244);
	setJa($5178);
	setJa($586B);
	setJa($5929);
	setJa($5C55);
	setJa($5E97);
	setJa($6DFB);
	setJa($7E8F);
	setJa($751C);
	setJa($8CBC);
	setJa($8EE2);
	setJa($985B);
	setJa($70B9);
	setJa($4F1D);
	setJa($6BBF);
	setJa($6FB1);
	setJa($7530);
	setJa($96FB);
	setJa($514E);
	setJa($5410);
	setJa($5835);
	setJa($5857);
	setJa($59AC);
	setJa($5C60);
	setJa($5F92);
	setJa($6597);
	setJa($675C);
	setJa($6E21);
	setJa($767B);
	setJa($83DF);
	setJa($8CED);
	setJa($9014);
	setJa($90FD);
	setJa($934D);
	setJa($7825);
	setJa($783A);
	setJa($52AA);
	setJa($5EA6);
	setJa($571F);
	setJa($5974);
	setJa($6012);
	setJa($5012);
	setJa($515A);
	setJa($51AC);
	setJa($51CD);
	setJa($5200);
	setJa($5510);
	setJa($5854);
	setJa($5858);
	setJa($5957);
	setJa($5B95);
	setJa($5CF6);
	setJa($5D8B);
	setJa($60BC);
	setJa($6295);
	setJa($642D);
	setJa($6771);
	setJa($6843);
	setJa($68BC);
	setJa($68DF);
	setJa($76D7);
	setJa($6DD8);
	setJa($6E6F);
	setJa($6D9B);
	setJa($706F);
	setJa($71C8);
	setJa($5F53);
	setJa($75D8);
	setJa($7977);
	setJa($7B49);
	setJa($7B54);
	setJa($7B52);
	setJa($7CD6);
	setJa($7D71);
	setJa($5230);
	setJa($8463);
	setJa($8569);
	setJa($85E4);
	setJa($8A0E);
	setJa($8B04);
	setJa($8C46);
	setJa($8E0F);
	setJa($9003);
	setJa($900F);
	setJa($9419);
	setJa($9676);
	setJa($982D);
	setJa($9A30);
	setJa($95D8);
	setJa($50CD);
	setJa($52D5);
	setJa($540C);
	setJa($5802);
	setJa($5C0E);
	setJa($61A7);
	setJa($649E);
	setJa($6D1E);
	setJa($77B3);
	setJa($7AE5);
	setJa($80F4);
	setJa($8404);
	setJa($9053);
	setJa($9285);
	setJa($5CE0);
	setJa($9D07);
	setJa($533F);
	setJa($5F97);
	setJa($5FB3);
	setJa($6D9C);
	setJa($7279);
	setJa($7763);
	setJa($79BF);
	setJa($7BE4);
	setJa($6BD2);
	setJa($72EC);
	setJa($8AAD);
	setJa($6803);
	setJa($6A61);
	setJa($51F8);
	setJa($7A81);
	setJa($6934);
	setJa($5C4A);
	setJa($9CF6);
	setJa($82EB);
	setJa($5BC5);
	setJa($9149);
	setJa($701E);
	setJa($5678);
	setJa($5C6F);
	setJa($60C7);
	setJa($6566);
	setJa($6C8C);
	setJa($8C5A);
	setJa($9041);
	setJa($9813);
	setJa($5451);
	setJa($66C7);
	setJa($920D);
	setJa($5948);
	setJa($90A3);
	setJa($5185);
	setJa($4E4D);
	setJa($51EA);
	setJa($8599);
	setJa($8B0E);
	setJa($7058);
	setJa($637A);
	setJa($934B);
	setJa($6962);
	setJa($99B4);
	setJa($7E04);
	setJa($7577);
	setJa($5357);
	setJa($6960);
	setJa($8EDF);
	setJa($96E3);
	setJa($6C5D);
	setJa($4E8C);
	setJa($5C3C);
	setJa($5F10);
	setJa($8FE9);
	setJa($5302);
	setJa($8CD1);
	setJa($8089);
	setJa($8679);
	setJa($5EFF);
	setJa($65E5);
	setJa($4E73);
	setJa($5165);
	setJa($5982);
	setJa($5C3F);
	setJa($97EE);
	setJa($4EFB);
	setJa($598A);
	setJa($5FCD);
	setJa($8A8D);
	setJa($6FE1);
	setJa($79B0);
	setJa($7962);
	setJa($5BE7);
	setJa($8471);
	setJa($732B);
	setJa($71B1);
	setJa($5E74);
	setJa($5FF5);
	setJa($637B);
	setJa($649A);
	setJa($71C3);
	setJa($7C98);
	setJa($4E43);
	setJa($5EFC);
	setJa($4E4B);
	setJa($57DC);
	setJa($56A2);
	setJa($60A9);
	setJa($6FC3);
	setJa($7D0D);
	setJa($80FD);
	setJa($8133);
	setJa($81BF);
	setJa($8FB2);
	setJa($8997);
	setJa($86A4);
	setJa($5DF4);
	setJa($628A);
	setJa($64AD);
	setJa($8987);
	setJa($6777);
	setJa($6CE2);
	setJa($6D3E);
	setJa($7436);
	setJa($7834);
	setJa($5A46);
	setJa($7F75);
	setJa($82AD);
	setJa($99AC);
	setJa($4FF3);
	setJa($5EC3);
	setJa($62DD);
	setJa($6392);
	setJa($6557);
	setJa($676F);
	setJa($76C3);
	setJa($724C);
	setJa($80CC);
	setJa($80BA);
	setJa($8F29);
	setJa($914D);
	setJa($500D);
	setJa($57F9);
	setJa($5A92);
	setJa($6885);
	setJa($6973);
	setJa($7164);
	setJa($72FD);
	setJa($8CB7);
	setJa($58F2);
	setJa($8CE0);
	setJa($966A);
	setJa($9019);
	setJa($877F);
	setJa($79E4);
	setJa($77E7);
	setJa($8429);
	setJa($4F2F);
	setJa($5265);
	setJa($535A);
	setJa($62CD);
	setJa($67CF);
	setJa($6CCA);
	setJa($767D);
	setJa($7B94);
	setJa($7C95);
	setJa($8236);
	setJa($8584);
	setJa($8FEB);
	setJa($66DD);
	setJa($6F20);
	setJa($7206);
	setJa($7E1B);
	setJa($83AB);
	setJa($99C1);
	setJa($9EA6);
	setJa($51FD);
	setJa($7BB1);
	setJa($7872);
	setJa($7BB8);
	setJa($8087);
	setJa($7B48);
	setJa($6AE8);
	setJa($5E61);
	setJa($808C);
	setJa($7551);
	setJa($7560);
	setJa($516B);
	setJa($9262);
	setJa($6E8C);
	setJa($767A);
	setJa($9197);
	setJa($9AEA);
	setJa($4F10);
	setJa($7F70);
	setJa($629C);
	setJa($7B4F);
	setJa($95A5);
	setJa($9CE9);
	setJa($567A);
	setJa($5859);
	setJa($86E4);
	setJa($96BC);
	setJa($4F34);
	setJa($5224);
	setJa($534A);
	setJa($53CD);
	setJa($53DB);
	setJa($5E06);
	setJa($642C);
	setJa($6591);
	setJa($677F);
	setJa($6C3E);
	setJa($6C4E);
	setJa($7248);
	setJa($72AF);
	setJa($73ED);
	setJa($7554);
	setJa($7E41);
	setJa($822C);
	setJa($85E9);
	setJa($8CA9);
	setJa($7BC4);
	setJa($91C6);
	setJa($7169);
	setJa($9812);
	setJa($98EF);
	setJa($633D);
	setJa($6669);
	setJa($756A);
	setJa($76E4);
	setJa($78D0);
	setJa($8543);
	setJa($86EE);
	setJa($532A);
	setJa($5351);
	setJa($5426);
	setJa($5983);
	setJa($5E87);
	setJa($5F7C);
	setJa($60B2);
	setJa($6249);
	setJa($6279);
	setJa($62AB);
	setJa($6590);
	setJa($6BD4);
	setJa($6CCC);
	setJa($75B2);
	setJa($76AE);
	setJa($7891);
	setJa($79D8);
	setJa($7DCB);
	setJa($7F77);
	setJa($80A5);
	setJa($88AB);
	setJa($8AB9);
	setJa($8CBB);
	setJa($907F);
	setJa($975E);
	setJa($98DB);
	setJa($6A0B);
	setJa($7C38);
	setJa($5099);
	setJa($5C3E);
	setJa($5FAE);
	setJa($6787);
	setJa($6BD8);
	setJa($7435);
	setJa($7709);
	setJa($7F8E);
	setJa($9F3B);
	setJa($67CA);
	setJa($7A17);
	setJa($5339);
	setJa($758B);
	setJa($9AED);
	setJa($5F66);
	setJa($819D);
	setJa($83F1);
	setJa($8098);
	setJa($5F3C);
	setJa($5FC5);
	setJa($7562);
	setJa($7B46);
	setJa($903C);
	setJa($6867);
	setJa($59EB);
	setJa($5A9B);
	setJa($7D10);
	setJa($767E);
	setJa($8B2C);
	setJa($4FF5);
	setJa($5F6A);
	setJa($6A19);
	setJa($6C37);
	setJa($6F02);
	setJa($74E2);
	setJa($7968);
	setJa($8868);
	setJa($8A55);
	setJa($8C79);
	setJa($5EDF);
	setJa($63CF);
	setJa($75C5);
	setJa($79D2);
	setJa($82D7);
	setJa($9328);
	setJa($92F2);
	setJa($849C);
	setJa($86ED);
	setJa($9C2D);
	setJa($54C1);
	setJa($5F6C);
	setJa($658C);
	setJa($6D5C);
	setJa($7015);
	setJa($8CA7);
	setJa($8CD3);
	setJa($983B);
	setJa($654F);
	setJa($74F6);
	setJa($4E0D);
	setJa($4ED8);
	setJa($57E0);
	setJa($592B);
	setJa($5A66);
	setJa($5BCC);
	setJa($51A8);
	setJa($5E03);
	setJa($5E9C);
	setJa($6016);
	setJa($6276);
	setJa($6577);
	setJa($65A7);
	setJa($666E);
	setJa($6D6E);
	setJa($7236);
	setJa($7B26);
	setJa($8150);
	setJa($819A);
	setJa($8299);
	setJa($8B5C);
	setJa($8CA0);
	setJa($8CE6);
	setJa($8D74);
	setJa($961C);
	setJa($9644);
	setJa($4FAE);
	setJa($64AB);
	setJa($6B66);
	setJa($821E);
	setJa($8461);
	setJa($856A);
	setJa($90E8);
	setJa($5C01);
	setJa($6953);
	setJa($98A8);
	setJa($847A);
	setJa($8557);
	setJa($4F0F);
	setJa($526F);
	setJa($5FA9);
	setJa($5E45);
	setJa($670D);
	setJa($798F);
	setJa($8179);
	setJa($8907);
	setJa($8986);
	setJa($6DF5);
	setJa($5F17);
	setJa($6255);
	setJa($6CB8);
	setJa($4ECF);
	setJa($7269);
	setJa($9B92);
	setJa($5206);
	setJa($543B);
	setJa($5674);
	setJa($58B3);
	setJa($61A4);
	setJa($626E);
	setJa($711A);
	setJa($596E);
	setJa($7C89);
	setJa($7CDE);
	setJa($7D1B);
	setJa($96F0);
	setJa($6587);
	setJa($805E);
	setJa($4E19);
	setJa($4F75);
	setJa($5175);
	setJa($5840);
	setJa($5E63);
	setJa($5E73);
	setJa($5F0A);
	setJa($67C4);
	setJa($4E26);
	setJa($853D);
	setJa($9589);
	setJa($965B);
	setJa($7C73);
	setJa($9801);
	setJa($50FB);
	setJa($58C1);
	setJa($7656);
	setJa($78A7);
	setJa($5225);
	setJa($77A5);
	setJa($8511);
	setJa($7B86);
	setJa($504F);
	setJa($5909);
	setJa($7247);
	setJa($7BC7);
	setJa($7DE8);
	setJa($8FBA);
	setJa($8FD4);
	setJa($904D);
	setJa($4FBF);
	setJa($52C9);
	setJa($5A29);
	setJa($5F01);
	setJa($97AD);
	setJa($4FDD);
	setJa($8217);
	setJa($92EA);
	setJa($5703);
	setJa($6355);
	setJa($6B69);
	setJa($752B);
	setJa($88DC);
	setJa($8F14);
	setJa($7A42);
	setJa($52DF);
	setJa($5893);
	setJa($6155);
	setJa($620A);
	setJa($66AE);
	setJa($6BCD);
	setJa($7C3F);
	setJa($83E9);
	setJa($5023);
	setJa($4FF8);
	setJa($5305);
	setJa($5446);
	setJa($5831);
	setJa($5949);
	setJa($5B9D);
	setJa($5CF0);
	setJa($5CEF);
	setJa($5D29);
	setJa($5E96);
	setJa($62B1);
	setJa($6367);
	setJa($653E);
	setJa($65B9);
	setJa($670B);
	setJa($6CD5);
	setJa($6CE1);
	setJa($70F9);
	setJa($7832);
	setJa($7E2B);
	setJa($80DE);
	setJa($82B3);
	setJa($840C);
	setJa($84EC);
	setJa($8702);
	setJa($8912);
	setJa($8A2A);
	setJa($8C4A);
	setJa($90A6);
	setJa($92D2);
	setJa($98FD);
	setJa($9CF3);
	setJa($9D6C);
	setJa($4E4F);
	setJa($4EA1);
	setJa($508D);
	setJa($5256);
	setJa($574A);
	setJa($59A8);
	setJa($5E3D);
	setJa($5FD8);
	setJa($5FD9);
	setJa($623F);
	setJa($66B4);
	setJa($671B);
	setJa($67D0);
	setJa($68D2);
	setJa($5192);
	setJa($7D21);
	setJa($80AA);
	setJa($81A8);
	setJa($8B00);
	setJa($8C8C);
	setJa($8CBF);
	setJa($927E);
	setJa($9632);
	setJa($5420);
	setJa($982C);
	setJa($5317);
	setJa($50D5);
	setJa($535C);
	setJa($58A8);
	setJa($64B2);
	setJa($6734);
	setJa($7267);
	setJa($7766);
	setJa($7A46);
	setJa($91E6);
	setJa($52C3);
	setJa($6CA1);
	setJa($6B86);
	setJa($5800);
	setJa($5E4C);
	setJa($5954);
	setJa($672C);
	setJa($7FFB);
	setJa($51E1);
	setJa($76C6);
	setJa($6469);
	setJa($78E8);
	setJa($9B54);
	setJa($9EBB);
	setJa($57CB);
	setJa($59B9);
	setJa($6627);
	setJa($679A);
	setJa($6BCE);
	setJa($54E9);
	setJa($69D9);
	setJa($5E55);
	setJa($819C);
	setJa($6795);
	setJa($9BAA);
	setJa($67FE);
	setJa($9C52);
	setJa($685D);
	setJa($4EA6);
	setJa($4FE3);
	setJa($53C8);
	setJa($62B9);
	setJa($672B);
	setJa($6CAB);
	setJa($8FC4);
	setJa($4FAD);
	setJa($7E6D);
	setJa($9EBF);
	setJa($4E07);
	setJa($6162);
	setJa($6E80);
	setJa($6F2B);
	setJa($8513);
	setJa($5473);
	setJa($672A);
	setJa($9B45);
	setJa($5DF3);
	setJa($7B95);
	setJa($5CAC);
	setJa($5BC6);
	setJa($871C);
	setJa($6E4A);
	setJa($84D1);
	setJa($7A14);
	setJa($8108);
	setJa($5999);
	setJa($7C8D);
	setJa($6C11);
	setJa($7720);
	setJa($52D9);
	setJa($5922);
	setJa($7121);
	setJa($725F);
	setJa($77DB);
	setJa($9727);
	setJa($9D61);
	setJa($690B);
	setJa($5A7F);
	setJa($5A18);
	setJa($51A5);
	setJa($540D);
	setJa($547D);
	setJa($660E);
	setJa($76DF);
	setJa($8FF7);
	setJa($9298);
	setJa($9CF4);
	setJa($59EA);
	setJa($725D);
	setJa($6EC5);
	setJa($514D);
	setJa($68C9);
	setJa($7DBF);
	setJa($7DEC);
	setJa($9762);
	setJa($9EBA);
	setJa($6478);
	setJa($6A21);
	setJa($8302);
	setJa($5984);
	setJa($5B5F);
	setJa($6BDB);
	setJa($731B);
	setJa($76F2);
	setJa($7DB2);
	setJa($8017);
	setJa($8499);
	setJa($5132);
	setJa($6728);
	setJa($9ED9);
	setJa($76EE);
	setJa($6762);
	setJa($52FF);
	setJa($9905);
	setJa($5C24);
	setJa($623B);
	setJa($7C7E);
	setJa($8CB0);
	setJa($554F);
	setJa($60B6);
	setJa($7D0B);
	setJa($9580);
	setJa($5301);
	setJa($4E5F);
	setJa($51B6);
	setJa($591C);
	setJa($723A);
	setJa($8036);
	setJa($91CE);
	setJa($5F25);
	setJa($77E2);
	setJa($5384);
	setJa($5F79);
	setJa($7D04);
	setJa($85AC);
	setJa($8A33);
	setJa($8E8D);
	setJa($9756);
	setJa($67F3);
	setJa($85AE);
	setJa($9453);
	setJa($6109);
	setJa($6108);
	setJa($6CB9);
	setJa($7652);
	setJa($8AED);
	setJa($8F38);
	setJa($552F);
	setJa($4F51);
	setJa($512A);
	setJa($52C7);
	setJa($53CB);
	setJa($5BA5);
	setJa($5E7D);
	setJa($60A0);
	setJa($6182);
	setJa($63D6);
	setJa($6709);
	setJa($67DA);
	setJa($6E67);
	setJa($6D8C);
	setJa($7336);
	setJa($7337);
	setJa($7531);
	setJa($7950);
	setJa($88D5);
	setJa($8A98);
	setJa($904A);
	setJa($9091);
	setJa($90F5);
	setJa($96C4);
	setJa($878D);
	setJa($5915);
	setJa($4E88);
	setJa($4F59);
	setJa($4E0E);
	setJa($8A89);
	setJa($8F3F);
	setJa($9810);
	setJa($50AD);
	setJa($5E7C);
	setJa($5996);
	setJa($5BB9);
	setJa($5EB8);
	setJa($63DA);
	setJa($63FA);
	setJa($64C1);
	setJa($66DC);
	setJa($694A);
	setJa($69D8);
	setJa($6D0B);
	setJa($6EB6);
	setJa($7194);
	setJa($7528);
	setJa($7AAF);
	setJa($7F8A);
	setJa($8000);
	setJa($8449);
	setJa($84C9);
	setJa($8981);
	setJa($8B21);
	setJa($8E0A);
	setJa($9065);
	setJa($967D);
	setJa($990A);
	setJa($617E);
	setJa($6291);
	setJa($6B32);
	setJa($6C83);
	setJa($6D74);
	setJa($7FCC);
	setJa($7FFC);
	setJa($6DC0);
	setJa($7F85);
	setJa($87BA);
	setJa($88F8);
	setJa($6765);
	setJa($83B1);
	setJa($983C);
	setJa($96F7);
	setJa($6D1B);
	setJa($7D61);
	setJa($843D);
	setJa($916A);
	setJa($4E71);
	setJa($5375);
	setJa($5D50);
	setJa($6B04);
	setJa($6FEB);
	setJa($85CD);
	setJa($862D);
	setJa($89A7);
	setJa($5229);
	setJa($540F);
	setJa($5C65);
	setJa($674E);
	setJa($68A8);
	setJa($7406);
	setJa($7483);
	setJa($75E2);
	setJa($88CF);
	setJa($88E1);
	setJa($91CC);
	setJa($96E2);
	setJa($9678);
	setJa($5F8B);
	setJa($7387);
	setJa($7ACB);
	setJa($844E);
	setJa($63A0);
	setJa($7565);
	setJa($5289);
	setJa($6D41);
	setJa($6E9C);
	setJa($7409);
	setJa($7559);
	setJa($786B);
	setJa($7C92);
	setJa($9686);
	setJa($7ADC);
	setJa($9F8D);
	setJa($4FB6);
	setJa($616E);
	setJa($65C5);
	setJa($865C);
	setJa($4E86);
	setJa($4EAE);
	setJa($50DA);
	setJa($4E21);
	setJa($51CC);
	setJa($5BEE);
	setJa($6599);
	setJa($6881);
	setJa($6DBC);
	setJa($731F);
	setJa($7642);
	setJa($77AD);
	setJa($7A1C);
	setJa($7CE7);
	setJa($826F);
	setJa($8AD2);
	setJa($907C);
	setJa($91CF);
	setJa($9675);
	setJa($9818);
	setJa($529B);
	setJa($7DD1);
	setJa($502B);
	setJa($5398);
	setJa($6797);
	setJa($6DCB);
	setJa($71D0);
	setJa($7433);
	setJa($81E8);
	setJa($8F2A);
	setJa($96A3);
	setJa($9C57);
	setJa($9E9F);
	setJa($7460);
	setJa($5841);
	setJa($6D99);
	setJa($7D2F);
	setJa($985E);
	setJa($4EE4);
	setJa($4F36);
	setJa($4F8B);
	setJa($51B7);
	setJa($52B1);
	setJa($5DBA);
	setJa($601C);
	setJa($73B2);
	setJa($793C);
	setJa($82D3);
	setJa($9234);
	setJa($96B7);
	setJa($96F6);
	setJa($970A);
	setJa($9E97);
	setJa($9F62);
	setJa($66A6);
	setJa($6B74);
	setJa($5217);
	setJa($52A3);
	setJa($70C8);
	setJa($88C2);
	setJa($5EC9);
	setJa($604B);
	setJa($6190);
	setJa($6F23);
	setJa($7149);
	setJa($7C3E);
	setJa($7DF4);
	setJa($806F);
	setJa($84EE);
	setJa($9023);
	setJa($932C);
	setJa($5442);
	setJa($9B6F);
	setJa($6AD3);
	setJa($7089);
	setJa($8CC2);
	setJa($8DEF);
	setJa($9732);
	setJa($52B4);
	setJa($5A41);
	setJa($5ECA);
	setJa($5F04);
	setJa($6717);
	setJa($697C);
	setJa($6994);
	setJa($6D6A);
	setJa($6F0F);
	setJa($7262);
	setJa($72FC);
	setJa($7BED);
	setJa($8001);
	setJa($807E);
	setJa($874B);
	setJa($90CE);
	setJa($516D);
	setJa($9E93);
	setJa($7984);
	setJa($808B);
	setJa($9332);
	setJa($8AD6);
	setJa($502D);
	setJa($548C);
	setJa($8A71);
	setJa($6B6A);
	setJa($8CC4);
	setJa($8107);
	setJa($60D1);
	setJa($67A0);
	setJa($9DF2);
	setJa($4E99);
	setJa($4E98);
	setJa($9C10);
	setJa($8A6B);
	setJa($85C1);
	setJa($8568);
	setJa($6900);
	setJa($6E7E);
	setJa($7897);
	setJa($8155);
	setJa($5F0C);
	setJa($4E10);
	setJa($4E15);
	setJa($4E2A);
	setJa($4E31);
	setJa($4E36);
	setJa($4E3C);
	setJa($4E3F);
	setJa($4E42);
	setJa($4E56);
	setJa($4E58);
	setJa($4E82);
	setJa($4E85);
	setJa($8C6B);
	setJa($4E8A);
	setJa($8212);
	setJa($5F0D);
	setJa($4E8E);
	setJa($4E9E);
	setJa($4E9F);
	setJa($4EA0);
	setJa($4EA2);
	setJa($4EB0);
	setJa($4EB3);
	setJa($4EB6);
	setJa($4ECE);
	setJa($4ECD);
	setJa($4EC4);
	setJa($4EC6);
	setJa($4EC2);
	setJa($4ED7);
	setJa($4EDE);
	setJa($4EED);
	setJa($4EDF);
	setJa($4EF7);
	setJa($4F09);
	setJa($4F5A);
	setJa($4F30);
	setJa($4F5B);
	setJa($4F5D);
	setJa($4F57);
	setJa($4F47);
	setJa($4F76);
	setJa($4F88);
	setJa($4F8F);
	setJa($4F98);
	setJa($4F7B);
	setJa($4F69);
	setJa($4F70);
	setJa($4F91);
	setJa($4F6F);
	setJa($4F86);
	setJa($4F96);
	setJa($5118);
	setJa($4FD4);
	setJa($4FDF);
	setJa($4FCE);
	setJa($4FD8);
	setJa($4FDB);
	setJa($4FD1);
	setJa($4FDA);
	setJa($4FD0);
	setJa($4FE4);
	setJa($4FE5);
	setJa($501A);
	setJa($5028);
	setJa($5014);
	setJa($502A);
	setJa($5025);
	setJa($5005);
	setJa($4F1C);
	setJa($4FF6);
	setJa($5021);
	setJa($5029);
	setJa($502C);
	setJa($4FFE);
	setJa($4FEF);
	setJa($5011);
	setJa($5006);
	setJa($5043);
	setJa($5047);
	setJa($6703);
	setJa($5055);
	setJa($5050);
	setJa($5048);
	setJa($505A);
	setJa($5056);
	setJa($506C);
	setJa($5078);
	setJa($5080);
	setJa($509A);
	setJa($5085);
	setJa($50B4);
	setJa($50B2);
	setJa($50C9);
	setJa($50CA);
	setJa($50B3);
	setJa($50C2);
	setJa($50D6);
	setJa($50DE);
	setJa($50E5);
	setJa($50ED);
	setJa($50E3);
	setJa($50EE);
	setJa($50F9);
	setJa($50F5);
	setJa($5109);
	setJa($5101);
	setJa($5102);
	setJa($5116);
	setJa($5115);
	setJa($5114);
	setJa($511A);
	setJa($5121);
	setJa($513A);
	setJa($5137);
	setJa($513C);
	setJa($513B);
	setJa($513F);
	setJa($5140);
	setJa($5152);
	setJa($514C);
	setJa($5154);
	setJa($5162);
	setJa($7AF8);
	setJa($5169);
	setJa($516A);
	setJa($516E);
	setJa($5180);
	setJa($5182);
	setJa($56D8);
	setJa($518C);
	setJa($5189);
	setJa($518F);
	setJa($5191);
	setJa($5193);
	setJa($5195);
	setJa($5196);
	setJa($51A4);
	setJa($51A6);
	setJa($51A2);
	setJa($51A9);
	setJa($51AA);
	setJa($51AB);
	setJa($51B3);
	setJa($51B1);
	setJa($51B2);
	setJa($51B0);
	setJa($51B5);
	setJa($51BD);
	setJa($51C5);
	setJa($51C9);
	setJa($51DB);
	setJa($51E0);
	setJa($8655);
	setJa($51E9);
	setJa($51ED);
	setJa($51F0);
	setJa($51F5);
	setJa($51FE);
	setJa($5204);
	setJa($520B);
	setJa($5214);
	setJa($520E);
	setJa($5227);
	setJa($522A);
	setJa($522E);
	setJa($5233);
	setJa($5239);
	setJa($524F);
	setJa($5244);
	setJa($524B);
	setJa($524C);
	setJa($525E);
	setJa($5254);
	setJa($526A);
	setJa($5274);
	setJa($5269);
	setJa($5273);
	setJa($527F);
	setJa($527D);
	setJa($528D);
	setJa($5294);
	setJa($5292);
	setJa($5271);
	setJa($5288);
	setJa($5291);
	setJa($8FA8);
	setJa($8FA7);
	setJa($52AC);
	setJa($52AD);
	setJa($52BC);
	setJa($52B5);
	setJa($52C1);
	setJa($52CD);
	setJa($52D7);
	setJa($52DE);
	setJa($52E3);
	setJa($52E6);
	setJa($98ED);
	setJa($52E0);
	setJa($52F3);
	setJa($52F5);
	setJa($52F8);
	setJa($52F9);
	setJa($5306);
	setJa($5308);
	setJa($7538);
	setJa($530D);
	setJa($5310);
	setJa($530F);
	setJa($5315);
	setJa($531A);
	setJa($5323);
	setJa($532F);
	setJa($5331);
	setJa($5333);
	setJa($5338);
	setJa($5340);
	setJa($5346);
	setJa($5345);
	setJa($4E17);
	setJa($5349);
	setJa($534D);
	setJa($51D6);
	setJa($535E);
	setJa($5369);
	setJa($536E);
	setJa($5918);
	setJa($537B);
	setJa($5377);
	setJa($5382);
	setJa($5396);
	setJa($53A0);
	setJa($53A6);
	setJa($53A5);
	setJa($53AE);
	setJa($53B0);
	setJa($53B6);
	setJa($53C3);
	setJa($7C12);
	setJa($96D9);
	setJa($53DF);
	setJa($66FC);
	setJa($71EE);
	setJa($53EE);
	setJa($53E8);
	setJa($53ED);
	setJa($53FA);
	setJa($5401);
	setJa($543D);
	setJa($5440);
	setJa($542C);
	setJa($542D);
	setJa($543C);
	setJa($542E);
	setJa($5436);
	setJa($5429);
	setJa($541D);
	setJa($544E);
	setJa($548F);
	setJa($5475);
	setJa($548E);
	setJa($545F);
	setJa($5471);
	setJa($5477);
	setJa($5470);
	setJa($5492);
	setJa($547B);
	setJa($5480);
	setJa($5476);
	setJa($5484);
	setJa($5490);
	setJa($5486);
	setJa($54C7);
	setJa($54A2);
	setJa($54B8);
	setJa($54A5);
	setJa($54AC);
	setJa($54C4);
	setJa($54C8);
	setJa($54A8);
	setJa($54AB);
	setJa($54C2);
	setJa($54A4);
	setJa($54BE);
	setJa($54BC);
	setJa($54D8);
	setJa($54E5);
	setJa($54E6);
	setJa($550F);
	setJa($5514);
	setJa($54FD);
	setJa($54EE);
	setJa($54ED);
	setJa($54FA);
	setJa($54E2);
	setJa($5539);
	setJa($5540);
	setJa($5563);
	setJa($554C);
	setJa($552E);
	setJa($555C);
	setJa($5545);
	setJa($5556);
	setJa($5557);
	setJa($5538);
	setJa($5533);
	setJa($555D);
	setJa($5599);
	setJa($5580);
	setJa($54AF);
	setJa($558A);
	setJa($559F);
	setJa($557B);
	setJa($557E);
	setJa($5598);
	setJa($559E);
	setJa($55AE);
	setJa($557C);
	setJa($5583);
	setJa($55A9);
	setJa($5587);
	setJa($55A8);
	setJa($55DA);
	setJa($55C5);
	setJa($55DF);
	setJa($55C4);
	setJa($55DC);
	setJa($55E4);
	setJa($55D4);
	setJa($5614);
	setJa($55F7);
	setJa($5616);
	setJa($55FE);
	setJa($55FD);
	setJa($561B);
	setJa($55F9);
	setJa($564E);
	setJa($5650);
	setJa($71DF);
	setJa($5634);
	setJa($5636);
	setJa($5632);
	setJa($5638);
	setJa($566B);
	setJa($5664);
	setJa($562F);
	setJa($566C);
	setJa($566A);
	setJa($5686);
	setJa($5680);
	setJa($568A);
	setJa($56A0);
	setJa($5694);
	setJa($568F);
	setJa($56A5);
	setJa($56AE);
	setJa($56B6);
	setJa($56B4);
	setJa($56C2);
	setJa($56BC);
	setJa($56C1);
	setJa($56C3);
	setJa($56C0);
	setJa($56C8);
	setJa($56CE);
	setJa($56D1);
	setJa($56D3);
	setJa($56D7);
	setJa($56EE);
	setJa($56F9);
	setJa($5700);
	setJa($56FF);
	setJa($5704);
	setJa($5709);
	setJa($5708);
	setJa($570B);
	setJa($570D);
	setJa($5713);
	setJa($5718);
	setJa($5716);
	setJa($55C7);
	setJa($571C);
	setJa($5726);
	setJa($5737);
	setJa($5738);
	setJa($574E);
	setJa($573B);
	setJa($5740);
	setJa($574F);
	setJa($5769);
	setJa($57C0);
	setJa($5788);
	setJa($5761);
	setJa($577F);
	setJa($5789);
	setJa($5793);
	setJa($57A0);
	setJa($57B3);
	setJa($57A4);
	setJa($57AA);
	setJa($57B0);
	setJa($57C3);
	setJa($57C6);
	setJa($57D4);
	setJa($57D2);
	setJa($57D3);
	setJa($580A);
	setJa($57D6);
	setJa($57E3);
	setJa($580B);
	setJa($5819);
	setJa($581D);
	setJa($5872);
	setJa($5821);
	setJa($5862);
	setJa($584B);
	setJa($5870);
	setJa($6BC0);
	setJa($5852);
	setJa($583D);
	setJa($5879);
	setJa($5885);
	setJa($58B9);
	setJa($589F);
	setJa($58AB);
	setJa($58BA);
	setJa($58DE);
	setJa($58BB);
	setJa($58B8);
	setJa($58AE);
	setJa($58C5);
	setJa($58D3);
	setJa($58D1);
	setJa($58D7);
	setJa($58D9);
	setJa($58D8);
	setJa($58E5);
	setJa($58DC);
	setJa($58E4);
	setJa($58DF);
	setJa($58EF);
	setJa($58FA);
	setJa($58F9);
	setJa($58FB);
	setJa($58FC);
	setJa($58FD);
	setJa($5902);
	setJa($590A);
	setJa($5910);
	setJa($591B);
	setJa($68A6);
	setJa($5925);
	setJa($592C);
	setJa($592D);
	setJa($5932);
	setJa($5938);
	setJa($593E);
	setJa($7AD2);
	setJa($5955);
	setJa($5950);
	setJa($594E);
	setJa($595A);
	setJa($5958);
	setJa($5962);
	setJa($5960);
	setJa($5967);
	setJa($596C);
	setJa($5969);
	setJa($5978);
	setJa($5981);
	setJa($599D);
	setJa($4F5E);
	setJa($4FAB);
	setJa($59A3);
	setJa($59B2);
	setJa($59C6);
	setJa($59E8);
	setJa($59DC);
	setJa($598D);
	setJa($59D9);
	setJa($59DA);
	setJa($5A25);
	setJa($5A1F);
	setJa($5A11);
	setJa($5A1C);
	setJa($5A09);
	setJa($5A1A);
	setJa($5A40);
	setJa($5A6C);
	setJa($5A49);
	setJa($5A35);
	setJa($5A36);
	setJa($5A62);
	setJa($5A6A);
	setJa($5A9A);
	setJa($5ABC);
	setJa($5ABE);
	setJa($5ACB);
	setJa($5AC2);
	setJa($5ABD);
	setJa($5AE3);
	setJa($5AD7);
	setJa($5AE6);
	setJa($5AE9);
	setJa($5AD6);
	setJa($5AFA);
	setJa($5AFB);
	setJa($5B0C);
	setJa($5B0B);
	setJa($5B16);
	setJa($5B32);
	setJa($5AD0);
	setJa($5B2A);
	setJa($5B36);
	setJa($5B3E);
	setJa($5B43);
	setJa($5B45);
	setJa($5B40);
	setJa($5B51);
	setJa($5B55);
	setJa($5B5A);
	setJa($5B5B);
	setJa($5B65);
	setJa($5B69);
	setJa($5B70);
	setJa($5B73);
	setJa($5B75);
	setJa($5B78);
	setJa($6588);
	setJa($5B7A);
	setJa($5B80);
	setJa($5B83);
	setJa($5BA6);
	setJa($5BB8);
	setJa($5BC3);
	setJa($5BC7);
	setJa($5BC9);
	setJa($5BD4);
	setJa($5BD0);
	setJa($5BE4);
	setJa($5BE6);
	setJa($5BE2);
	setJa($5BDE);
	setJa($5BE5);
	setJa($5BEB);
	setJa($5BF0);
	setJa($5BF6);
	setJa($5BF3);
	setJa($5C05);
	setJa($5C07);
	setJa($5C08);
	setJa($5C0D);
	setJa($5C13);
	setJa($5C20);
	setJa($5C22);
	setJa($5C28);
	setJa($5C38);
	setJa($5C39);
	setJa($5C41);
	setJa($5C46);
	setJa($5C4E);
	setJa($5C53);
	setJa($5C50);
	setJa($5C4F);
	setJa($5B71);
	setJa($5C6C);
	setJa($5C6E);
	setJa($4E62);
	setJa($5C76);
	setJa($5C79);
	setJa($5C8C);
	setJa($5C91);
	setJa($5C94);
	setJa($599B);
	setJa($5CAB);
	setJa($5CBB);
	setJa($5CB6);
	setJa($5CBC);
	setJa($5CB7);
	setJa($5CC5);
	setJa($5CBE);
	setJa($5CC7);
	setJa($5CD9);
	setJa($5CE9);
	setJa($5CFD);
	setJa($5CFA);
	setJa($5CED);
	setJa($5D8C);
	setJa($5CEA);
	setJa($5D0B);
	setJa($5D15);
	setJa($5D17);
	setJa($5D5C);
	setJa($5D1F);
	setJa($5D1B);
	setJa($5D11);
	setJa($5D14);
	setJa($5D22);
	setJa($5D1A);
	setJa($5D19);
	setJa($5D18);
	setJa($5D4C);
	setJa($5D52);
	setJa($5D4E);
	setJa($5D4B);
	setJa($5D6C);
	setJa($5D73);
	setJa($5D76);
	setJa($5D87);
	setJa($5D84);
	setJa($5D82);
	setJa($5DA2);
	setJa($5D9D);
	setJa($5DAC);
	setJa($5DAE);
	setJa($5DBD);
	setJa($5D90);
	setJa($5DB7);
	setJa($5DBC);
	setJa($5DC9);
	setJa($5DCD);
	setJa($5DD3);
	setJa($5DD2);
	setJa($5DD6);
	setJa($5DDB);
	setJa($5DEB);
	setJa($5DF2);
	setJa($5DF5);
	setJa($5E0B);
	setJa($5E1A);
	setJa($5E19);
	setJa($5E11);
	setJa($5E1B);
	setJa($5E36);
	setJa($5E37);
	setJa($5E44);
	setJa($5E43);
	setJa($5E40);
	setJa($5E4E);
	setJa($5E57);
	setJa($5E54);
	setJa($5E5F);
	setJa($5E62);
	setJa($5E64);
	setJa($5E47);
	setJa($5E75);
	setJa($5E76);
	setJa($5E7A);
	setJa($9EBC);
	setJa($5E7F);
	setJa($5EA0);
	setJa($5EC1);
	setJa($5EC2);
	setJa($5EC8);
	setJa($5ED0);
	setJa($5ECF);
	setJa($5ED6);
	setJa($5EE3);
	setJa($5EDD);
	setJa($5EDA);
	setJa($5EDB);
	setJa($5EE2);
	setJa($5EE1);
	setJa($5EE8);
	setJa($5EE9);
	setJa($5EEC);
	setJa($5EF1);
	setJa($5EF3);
	setJa($5EF0);
	setJa($5EF4);
	setJa($5EF8);
	setJa($5EFE);
	setJa($5F03);
	setJa($5F09);
	setJa($5F5D);
	setJa($5F5C);
	setJa($5F0B);
	setJa($5F11);
	setJa($5F16);
	setJa($5F29);
	setJa($5F2D);
	setJa($5F38);
	setJa($5F41);
	setJa($5F48);
	setJa($5F4C);
	setJa($5F4E);
	setJa($5F2F);
	setJa($5F51);
	setJa($5F56);
	setJa($5F57);
	setJa($5F59);
	setJa($5F61);
	setJa($5F6D);
	setJa($5F73);
	setJa($5F77);
	setJa($5F83);
	setJa($5F82);
	setJa($5F7F);
	setJa($5F8A);
	setJa($5F88);
	setJa($5F91);
	setJa($5F87);
	setJa($5F9E);
	setJa($5F99);
	setJa($5F98);
	setJa($5FA0);
	setJa($5FA8);
	setJa($5FAD);
	setJa($5FBC);
	setJa($5FD6);
	setJa($5FFB);
	setJa($5FE4);
	setJa($5FF8);
	setJa($5FF1);
	setJa($5FDD);
	setJa($60B3);
	setJa($5FFF);
	setJa($6021);
	setJa($6060);
	setJa($6019);
	setJa($6010);
	setJa($6029);
	setJa($600E);
	setJa($6031);
	setJa($601B);
	setJa($6015);
	setJa($602B);
	setJa($6026);
	setJa($600F);
	setJa($603A);
	setJa($605A);
	setJa($6041);
	setJa($606A);
	setJa($6077);
	setJa($605F);
	setJa($604A);
	setJa($6046);
	setJa($604D);
	setJa($6063);
	setJa($6043);
	setJa($6064);
	setJa($6042);
	setJa($606C);
	setJa($606B);
	setJa($6059);
	setJa($6081);
	setJa($608D);
	setJa($60E7);
	setJa($6083);
	setJa($609A);
	setJa($6084);
	setJa($609B);
	setJa($6096);
	setJa($6097);
	setJa($6092);
	setJa($60A7);
	setJa($608B);
	setJa($60E1);
	setJa($60B8);
	setJa($60E0);
	setJa($60D3);
	setJa($60B4);
	setJa($5FF0);
	setJa($60BD);
	setJa($60C6);
	setJa($60B5);
	setJa($60D8);
	setJa($614D);
	setJa($6115);
	setJa($6106);
	setJa($60F6);
	setJa($60F7);
	setJa($6100);
	setJa($60F4);
	setJa($60FA);
	setJa($6103);
	setJa($6121);
	setJa($60FB);
	setJa($60F1);
	setJa($610D);
	setJa($610E);
	setJa($6147);
	setJa($613E);
	setJa($6128);
	setJa($6127);
	setJa($614A);
	setJa($613F);
	setJa($613C);
	setJa($612C);
	setJa($6134);
	setJa($613D);
	setJa($6142);
	setJa($6144);
	setJa($6173);
	setJa($6177);
	setJa($6158);
	setJa($6159);
	setJa($615A);
	setJa($616B);
	setJa($6174);
	setJa($616F);
	setJa($6165);
	setJa($6171);
	setJa($615F);
	setJa($615D);
	setJa($6153);
	setJa($6175);
	setJa($6199);
	setJa($6196);
	setJa($6187);
	setJa($61AC);
	setJa($6194);
	setJa($619A);
	setJa($618A);
	setJa($6191);
	setJa($61AB);
	setJa($61AE);
	setJa($61CC);
	setJa($61CA);
	setJa($61C9);
	setJa($61F7);
	setJa($61C8);
	setJa($61C3);
	setJa($61C6);
	setJa($61BA);
	setJa($61CB);
	setJa($7F79);
	setJa($61CD);
	setJa($61E6);
	setJa($61E3);
	setJa($61F6);
	setJa($61FA);
	setJa($61F4);
	setJa($61FF);
	setJa($61FD);
	setJa($61FC);
	setJa($61FE);
	setJa($6200);
	setJa($6208);
	setJa($6209);
	setJa($620D);
	setJa($620C);
	setJa($6214);
	setJa($621B);
	setJa($621E);
	setJa($6221);
	setJa($622A);
	setJa($622E);
	setJa($6230);
	setJa($6232);
	setJa($6233);
	setJa($6241);
	setJa($624E);
	setJa($625E);
	setJa($6263);
	setJa($625B);
	setJa($6260);
	setJa($6268);
	setJa($627C);
	setJa($6282);
	setJa($6289);
	setJa($627E);
	setJa($6292);
	setJa($6293);
	setJa($6296);
	setJa($62D4);
	setJa($6283);
	setJa($6294);
	setJa($62D7);
	setJa($62D1);
	setJa($62BB);
	setJa($62CF);
	setJa($62FF);
	setJa($62C6);
	setJa($64D4);
	setJa($62C8);
	setJa($62DC);
	setJa($62CC);
	setJa($62CA);
	setJa($62C2);
	setJa($62C7);
	setJa($629B);
	setJa($62C9);
	setJa($630C);
	setJa($62EE);
	setJa($62F1);
	setJa($6327);
	setJa($6302);
	setJa($6308);
	setJa($62EF);
	setJa($62F5);
	setJa($6350);
	setJa($633E);
	setJa($634D);
	setJa($641C);
	setJa($634F);
	setJa($6396);
	setJa($638E);
	setJa($6380);
	setJa($63AB);
	setJa($6376);
	setJa($63A3);
	setJa($638F);
	setJa($6389);
	setJa($639F);
	setJa($63B5);
	setJa($636B);
	setJa($6369);
	setJa($63BE);
	setJa($63E9);
	setJa($63C0);
	setJa($63C6);
	setJa($63E3);
	setJa($63C9);
	setJa($63D2);
	setJa($63F6);
	setJa($63C4);
	setJa($6416);
	setJa($6434);
	setJa($6406);
	setJa($6413);
	setJa($6426);
	setJa($6436);
	setJa($651D);
	setJa($6417);
	setJa($6428);
	setJa($640F);
	setJa($6467);
	setJa($646F);
	setJa($6476);
	setJa($644E);
	setJa($652A);
	setJa($6495);
	setJa($6493);
	setJa($64A5);
	setJa($64A9);
	setJa($6488);
	setJa($64BC);
	setJa($64DA);
	setJa($64D2);
	setJa($64C5);
	setJa($64C7);
	setJa($64BB);
	setJa($64D8);
	setJa($64C2);
	setJa($64F1);
	setJa($64E7);
	setJa($8209);
	setJa($64E0);
	setJa($64E1);
	setJa($62AC);
	setJa($64E3);
	setJa($64EF);
	setJa($652C);
	setJa($64F6);
	setJa($64F4);
	setJa($64F2);
	setJa($64FA);
	setJa($6500);
	setJa($64FD);
	setJa($6518);
	setJa($651C);
	setJa($6505);
	setJa($6524);
	setJa($6523);
	setJa($652B);
	setJa($6534);
	setJa($6535);
	setJa($6537);
	setJa($6536);
	setJa($6538);
	setJa($754B);
	setJa($6548);
	setJa($6556);
	setJa($6555);
	setJa($654D);
	setJa($6558);
	setJa($655E);
	setJa($655D);
	setJa($6572);
	setJa($6578);
	setJa($6582);
	setJa($6583);
	setJa($8B8A);
	setJa($659B);
	setJa($659F);
	setJa($65AB);
	setJa($65B7);
	setJa($65C3);
	setJa($65C6);
	setJa($65C1);
	setJa($65C4);
	setJa($65CC);
	setJa($65D2);
	setJa($65DB);
	setJa($65D9);
	setJa($65E0);
	setJa($65E1);
	setJa($65F1);
	setJa($6772);
	setJa($660A);
	setJa($6603);
	setJa($65FB);
	setJa($6773);
	setJa($6635);
	setJa($6636);
	setJa($6634);
	setJa($661C);
	setJa($664F);
	setJa($6644);
	setJa($6649);
	setJa($6641);
	setJa($665E);
	setJa($665D);
	setJa($6664);
	setJa($6667);
	setJa($6668);
	setJa($665F);
	setJa($6662);
	setJa($6670);
	setJa($6683);
	setJa($6688);
	setJa($668E);
	setJa($6689);
	setJa($6684);
	setJa($6698);
	setJa($669D);
	setJa($66C1);
	setJa($66B9);
	setJa($66C9);
	setJa($66BE);
	setJa($66BC);
	setJa($66C4);
	setJa($66B8);
	setJa($66D6);
	setJa($66DA);
	setJa($66E0);
	setJa($663F);
	setJa($66E6);
	setJa($66E9);
	setJa($66F0);
	setJa($66F5);
	setJa($66F7);
	setJa($670F);
	setJa($6716);
	setJa($671E);
	setJa($6726);
	setJa($6727);
	setJa($9738);
	setJa($672E);
	setJa($673F);
	setJa($6736);
	setJa($6741);
	setJa($6738);
	setJa($6737);
	setJa($6746);
	setJa($675E);
	setJa($6760);
	setJa($6759);
	setJa($6763);
	setJa($6764);
	setJa($6789);
	setJa($6770);
	setJa($67A9);
	setJa($677C);
	setJa($676A);
	setJa($678C);
	setJa($678B);
	setJa($67A6);
	setJa($67A1);
	setJa($6785);
	setJa($67B7);
	setJa($67EF);
	setJa($67B4);
	setJa($67EC);
	setJa($67B3);
	setJa($67E9);
	setJa($67B8);
	setJa($67E4);
	setJa($67DE);
	setJa($67DD);
	setJa($67E2);
	setJa($67EE);
	setJa($67B9);
	setJa($67CE);
	setJa($67C6);
	setJa($67E7);
	setJa($6A9C);
	setJa($681E);
	setJa($6846);
	setJa($6829);
	setJa($6840);
	setJa($684D);
	setJa($6832);
	setJa($684E);
	setJa($68B3);
	setJa($682B);
	setJa($6859);
	setJa($6863);
	setJa($6877);
	setJa($687F);
	setJa($689F);
	setJa($688F);
	setJa($68AD);
	setJa($6894);
	setJa($689D);
	setJa($689B);
	setJa($6883);
	setJa($6AAE);
	setJa($68B9);
	setJa($6874);
	setJa($68B5);
	setJa($68A0);
	setJa($68BA);
	setJa($690F);
	setJa($688D);
	setJa($687E);
	setJa($6901);
	setJa($68CA);
	setJa($6908);
	setJa($68D8);
	setJa($6922);
	setJa($6926);
	setJa($68E1);
	setJa($690C);
	setJa($68CD);
	setJa($68D4);
	setJa($68E7);
	setJa($68D5);
	setJa($6936);
	setJa($6912);
	setJa($6904);
	setJa($68D7);
	setJa($68E3);
	setJa($6925);
	setJa($68F9);
	setJa($68E0);
	setJa($68EF);
	setJa($6928);
	setJa($692A);
	setJa($691A);
	setJa($6923);
	setJa($6921);
	setJa($68C6);
	setJa($6979);
	setJa($6977);
	setJa($695C);
	setJa($6978);
	setJa($696B);
	setJa($6954);
	setJa($697E);
	setJa($696E);
	setJa($6939);
	setJa($6974);
	setJa($693D);
	setJa($6959);
	setJa($6930);
	setJa($6961);
	setJa($695E);
	setJa($695D);
	setJa($6981);
	setJa($696A);
	setJa($69B2);
	setJa($69AE);
	setJa($69D0);
	setJa($69BF);
	setJa($69C1);
	setJa($69D3);
	setJa($69BE);
	setJa($69CE);
	setJa($5BE8);
	setJa($69CA);
	setJa($69DD);
	setJa($69BB);
	setJa($69C3);
	setJa($69A7);
	setJa($6A2E);
	setJa($6991);
	setJa($69A0);
	setJa($699C);
	setJa($6995);
	setJa($69B4);
	setJa($69DE);
	setJa($69E8);
	setJa($6A02);
	setJa($6A1B);
	setJa($69FF);
	setJa($6B0A);
	setJa($69F9);
	setJa($69F2);
	setJa($69E7);
	setJa($6A05);
	setJa($69B1);
	setJa($6A1E);
	setJa($69ED);
	setJa($6A14);
	setJa($69EB);
	setJa($6A0A);
	setJa($6A12);
	setJa($6AC1);
	setJa($6A23);
	setJa($6A13);
	setJa($6A44);
	setJa($6A0C);
	setJa($6A72);
	setJa($6A36);
	setJa($6A78);
	setJa($6A47);
	setJa($6A62);
	setJa($6A59);
	setJa($6A66);
	setJa($6A48);
	setJa($6A38);
	setJa($6A22);
	setJa($6A90);
	setJa($6A8D);
	setJa($6AA0);
	setJa($6A84);
	setJa($6AA2);
	setJa($6AA3);
	setJa($6A97);
	setJa($8617);
	setJa($6ABB);
	setJa($6AC3);
	setJa($6AC2);
	setJa($6AB8);
	setJa($6AB3);
	setJa($6AAC);
	setJa($6ADE);
	setJa($6AD1);
	setJa($6ADF);
	setJa($6AAA);
	setJa($6ADA);
	setJa($6AEA);
	setJa($6AFB);
	setJa($6B05);
	setJa($8616);
	setJa($6AFA);
	setJa($6B12);
	setJa($6B16);
	setJa($9B31);
	setJa($6B1F);
	setJa($6B38);
	setJa($6B37);
	setJa($76DC);
	setJa($6B39);
	setJa($98EE);
	setJa($6B47);
	setJa($6B43);
	setJa($6B49);
	setJa($6B50);
	setJa($6B59);
	setJa($6B54);
	setJa($6B5B);
	setJa($6B5F);
	setJa($6B61);
	setJa($6B78);
	setJa($6B79);
	setJa($6B7F);
	setJa($6B80);
	setJa($6B84);
	setJa($6B83);
	setJa($6B8D);
	setJa($6B98);
	setJa($6B95);
	setJa($6B9E);
	setJa($6BA4);
	setJa($6BAA);
	setJa($6BAB);
	setJa($6BAF);
	setJa($6BB2);
	setJa($6BB1);
	setJa($6BB3);
	setJa($6BB7);
	setJa($6BBC);
	setJa($6BC6);
	setJa($6BCB);
	setJa($6BD3);
	setJa($6BDF);
	setJa($6BEC);
	setJa($6BEB);
	setJa($6BF3);
	setJa($6BEF);
	setJa($9EBE);
	setJa($6C08);
	setJa($6C13);
	setJa($6C14);
	setJa($6C1B);
	setJa($6C24);
	setJa($6C23);
	setJa($6C5E);
	setJa($6C55);
	setJa($6C62);
	setJa($6C6A);
	setJa($6C82);
	setJa($6C8D);
	setJa($6C9A);
	setJa($6C81);
	setJa($6C9B);
	setJa($6C7E);
	setJa($6C68);
	setJa($6C73);
	setJa($6C92);
	setJa($6C90);
	setJa($6CC4);
	setJa($6CF1);
	setJa($6CD3);
	setJa($6CBD);
	setJa($6CD7);
	setJa($6CC5);
	setJa($6CDD);
	setJa($6CAE);
	setJa($6CB1);
	setJa($6CBE);
	setJa($6CBA);
	setJa($6CDB);
	setJa($6CEF);
	setJa($6CD9);
	setJa($6CEA);
	setJa($6D1F);
	setJa($884D);
	setJa($6D36);
	setJa($6D2B);
	setJa($6D3D);
	setJa($6D38);
	setJa($6D19);
	setJa($6D35);
	setJa($6D33);
	setJa($6D12);
	setJa($6D0C);
	setJa($6D63);
	setJa($6D93);
	setJa($6D64);
	setJa($6D5A);
	setJa($6D79);
	setJa($6D59);
	setJa($6D8E);
	setJa($6D95);
	setJa($6FE4);
	setJa($6D85);
	setJa($6DF9);
	setJa($6E15);
	setJa($6E0A);
	setJa($6DB5);
	setJa($6DC7);
	setJa($6DE6);
	setJa($6DB8);
	setJa($6DC6);
	setJa($6DEC);
	setJa($6DDE);
	setJa($6DCC);
	setJa($6DE8);
	setJa($6DD2);
	setJa($6DC5);
	setJa($6DFA);
	setJa($6DD9);
	setJa($6DE4);
	setJa($6DD5);
	setJa($6DEA);
	setJa($6DEE);
	setJa($6E2D);
	setJa($6E6E);
	setJa($6E2E);
	setJa($6E19);
	setJa($6E72);
	setJa($6E5F);
	setJa($6E3E);
	setJa($6E23);
	setJa($6E6B);
	setJa($6E2B);
	setJa($6E76);
	setJa($6E4D);
	setJa($6E1F);
	setJa($6E43);
	setJa($6E3A);
	setJa($6E4E);
	setJa($6E24);
	setJa($6EFF);
	setJa($6E1D);
	setJa($6E38);
	setJa($6E82);
	setJa($6EAA);
	setJa($6E98);
	setJa($6EC9);
	setJa($6EB7);
	setJa($6ED3);
	setJa($6EBD);
	setJa($6EAF);
	setJa($6EC4);
	setJa($6EB2);
	setJa($6ED4);
	setJa($6ED5);
	setJa($6E8F);
	setJa($6EA5);
	setJa($6EC2);
	setJa($6E9F);
	setJa($6F41);
	setJa($6F11);
	setJa($704C);
	setJa($6EEC);
	setJa($6EF8);
	setJa($6EFE);
	setJa($6F3F);
	setJa($6EF2);
	setJa($6F31);
	setJa($6EEF);
	setJa($6F32);
	setJa($6ECC);
	setJa($6F3E);
	setJa($6F13);
	setJa($6EF7);
	setJa($6F86);
	setJa($6F7A);
	setJa($6F78);
	setJa($6F81);
	setJa($6F80);
	setJa($6F6F);
	setJa($6F5B);
	setJa($6FF3);
	setJa($6F6D);
	setJa($6F82);
	setJa($6F7C);
	setJa($6F58);
	setJa($6F8E);
	setJa($6F91);
	setJa($6FC2);
	setJa($6F66);
	setJa($6FB3);
	setJa($6FA3);
	setJa($6FA1);
	setJa($6FA4);
	setJa($6FB9);
	setJa($6FC6);
	setJa($6FAA);
	setJa($6FDF);
	setJa($6FD5);
	setJa($6FEC);
	setJa($6FD4);
	setJa($6FD8);
	setJa($6FF1);
	setJa($6FEE);
	setJa($6FDB);
	setJa($7009);
	setJa($700B);
	setJa($6FFA);
	setJa($7011);
	setJa($7001);
	setJa($700F);
	setJa($6FFE);
	setJa($701B);
	setJa($701A);
	setJa($6F74);
	setJa($701D);
	setJa($7018);
	setJa($701F);
	setJa($7030);
	setJa($703E);
	setJa($7032);
	setJa($7051);
	setJa($7063);
	setJa($7099);
	setJa($7092);
	setJa($70AF);
	setJa($70F1);
	setJa($70AC);
	setJa($70B8);
	setJa($70B3);
	setJa($70AE);
	setJa($70DF);
	setJa($70CB);
	setJa($70DD);
	setJa($70D9);
	setJa($7109);
	setJa($70FD);
	setJa($711C);
	setJa($7119);
	setJa($7165);
	setJa($7155);
	setJa($7188);
	setJa($7166);
	setJa($7162);
	setJa($714C);
	setJa($7156);
	setJa($716C);
	setJa($718F);
	setJa($71FB);
	setJa($7184);
	setJa($7195);
	setJa($71A8);
	setJa($71AC);
	setJa($71D7);
	setJa($71B9);
	setJa($71BE);
	setJa($71D2);
	setJa($71C9);
	setJa($71D4);
	setJa($71CE);
	setJa($71E0);
	setJa($71EC);
	setJa($71E7);
	setJa($71F5);
	setJa($71FC);
	setJa($71F9);
	setJa($71FF);
	setJa($720D);
	setJa($7210);
	setJa($721B);
	setJa($7228);
	setJa($722D);
	setJa($722C);
	setJa($7230);
	setJa($7232);
	setJa($723B);
	setJa($723C);
	setJa($723F);
	setJa($7240);
	setJa($7246);
	setJa($724B);
	setJa($7258);
	setJa($7274);
	setJa($727E);
	setJa($7282);
	setJa($7281);
	setJa($7287);
	setJa($7292);
	setJa($7296);
	setJa($72A2);
	setJa($72A7);
	setJa($72B9);
	setJa($72B2);
	setJa($72C3);
	setJa($72C6);
	setJa($72C4);
	setJa($72CE);
	setJa($72D2);
	setJa($72E2);
	setJa($72E0);
	setJa($72E1);
	setJa($72F9);
	setJa($72F7);
	setJa($500F);
	setJa($7317);
	setJa($730A);
	setJa($731C);
	setJa($7316);
	setJa($731D);
	setJa($7334);
	setJa($732F);
	setJa($7329);
	setJa($7325);
	setJa($733E);
	setJa($734E);
	setJa($734F);
	setJa($9ED8);
	setJa($7357);
	setJa($736A);
	setJa($7368);
	setJa($7370);
	setJa($7378);
	setJa($7375);
	setJa($737B);
	setJa($737A);
	setJa($73C8);
	setJa($73B3);
	setJa($73CE);
	setJa($73BB);
	setJa($73C0);
	setJa($73E5);
	setJa($73EE);
	setJa($73DE);
	setJa($74A2);
	setJa($7405);
	setJa($746F);
	setJa($7425);
	setJa($73F8);
	setJa($7432);
	setJa($743A);
	setJa($7455);
	setJa($743F);
	setJa($745F);
	setJa($7459);
	setJa($7441);
	setJa($745C);
	setJa($7469);
	setJa($7470);
	setJa($7463);
	setJa($746A);
	setJa($7476);
	setJa($747E);
	setJa($748B);
	setJa($749E);
	setJa($74A7);
	setJa($74CA);
	setJa($74CF);
	setJa($74D4);
	setJa($73F1);
	setJa($74E0);
	setJa($74E3);
	setJa($74E7);
	setJa($74E9);
	setJa($74EE);
	setJa($74F2);
	setJa($74F0);
	setJa($74F1);
	setJa($74F8);
	setJa($74F7);
	setJa($7504);
	setJa($7503);
	setJa($7505);
	setJa($750C);
	setJa($750E);
	setJa($750D);
	setJa($7515);
	setJa($7513);
	setJa($751E);
	setJa($7526);
	setJa($752C);
	setJa($753C);
	setJa($7544);
	setJa($754D);
	setJa($754A);
	setJa($7549);
	setJa($755B);
	setJa($7546);
	setJa($755A);
	setJa($7569);
	setJa($7564);
	setJa($7567);
	setJa($756B);
	setJa($756D);
	setJa($7578);
	setJa($7576);
	setJa($7586);
	setJa($7587);
	setJa($7574);
	setJa($758A);
	setJa($7589);
	setJa($7582);
	setJa($7594);
	setJa($759A);
	setJa($759D);
	setJa($75A5);
	setJa($75A3);
	setJa($75C2);
	setJa($75B3);
	setJa($75C3);
	setJa($75B5);
	setJa($75BD);
	setJa($75B8);
	setJa($75BC);
	setJa($75B1);
	setJa($75CD);
	setJa($75CA);
	setJa($75D2);
	setJa($75D9);
	setJa($75E3);
	setJa($75DE);
	setJa($75FE);
	setJa($75FF);
	setJa($75FC);
	setJa($7601);
	setJa($75F0);
	setJa($75FA);
	setJa($75F2);
	setJa($75F3);
	setJa($760B);
	setJa($760D);
	setJa($7609);
	setJa($761F);
	setJa($7627);
	setJa($7620);
	setJa($7621);
	setJa($7622);
	setJa($7624);
	setJa($7634);
	setJa($7630);
	setJa($763B);
	setJa($7647);
	setJa($7648);
	setJa($7646);
	setJa($765C);
	setJa($7658);
	setJa($7661);
	setJa($7662);
	setJa($7668);
	setJa($7669);
	setJa($766A);
	setJa($7667);
	setJa($766C);
	setJa($7670);
	setJa($7672);
	setJa($7676);
	setJa($7678);
	setJa($767C);
	setJa($7680);
	setJa($7683);
	setJa($7688);
	setJa($768B);
	setJa($768E);
	setJa($7696);
	setJa($7693);
	setJa($7699);
	setJa($769A);
	setJa($76B0);
	setJa($76B4);
	setJa($76B8);
	setJa($76B9);
	setJa($76BA);
	setJa($76C2);
	setJa($76CD);
	setJa($76D6);
	setJa($76D2);
	setJa($76DE);
	setJa($76E1);
	setJa($76E5);
	setJa($76E7);
	setJa($76EA);
	setJa($862F);
	setJa($76FB);
	setJa($7708);
	setJa($7707);
	setJa($7704);
	setJa($7729);
	setJa($7724);
	setJa($771E);
	setJa($7725);
	setJa($7726);
	setJa($771B);
	setJa($7737);
	setJa($7738);
	setJa($7747);
	setJa($775A);
	setJa($7768);
	setJa($776B);
	setJa($775B);
	setJa($7765);
	setJa($777F);
	setJa($777E);
	setJa($7779);
	setJa($778E);
	setJa($778B);
	setJa($7791);
	setJa($77A0);
	setJa($779E);
	setJa($77B0);
	setJa($77B6);
	setJa($77B9);
	setJa($77BF);
	setJa($77BC);
	setJa($77BD);
	setJa($77BB);
	setJa($77C7);
	setJa($77CD);
	setJa($77D7);
	setJa($77DA);
	setJa($77DC);
	setJa($77E3);
	setJa($77EE);
	setJa($77FC);
	setJa($780C);
	setJa($7812);
	setJa($7926);
	setJa($7820);
	setJa($792A);
	setJa($7845);
	setJa($788E);
	setJa($7874);
	setJa($7886);
	setJa($787C);
	setJa($789A);
	setJa($788C);
	setJa($78A3);
	setJa($78B5);
	setJa($78AA);
	setJa($78AF);
	setJa($78D1);
	setJa($78C6);
	setJa($78CB);
	setJa($78D4);
	setJa($78BE);
	setJa($78BC);
	setJa($78C5);
	setJa($78CA);
	setJa($78EC);
	setJa($78E7);
	setJa($78DA);
	setJa($78FD);
	setJa($78F4);
	setJa($7907);
	setJa($7912);
	setJa($7911);
	setJa($7919);
	setJa($792C);
	setJa($792B);
	setJa($7940);
	setJa($7960);
	setJa($7957);
	setJa($795F);
	setJa($795A);
	setJa($7955);
	setJa($7953);
	setJa($797A);
	setJa($797F);
	setJa($798A);
	setJa($799D);
	setJa($79A7);
	setJa($9F4B);
	setJa($79AA);
	setJa($79AE);
	setJa($79B3);
	setJa($79B9);
	setJa($79BA);
	setJa($79C9);
	setJa($79D5);
	setJa($79E7);
	setJa($79EC);
	setJa($79E1);
	setJa($79E3);
	setJa($7A08);
	setJa($7A0D);
	setJa($7A18);
	setJa($7A19);
	setJa($7A20);
	setJa($7A1F);
	setJa($7980);
	setJa($7A31);
	setJa($7A3B);
	setJa($7A3E);
	setJa($7A37);
	setJa($7A43);
	setJa($7A57);
	setJa($7A49);
	setJa($7A61);
	setJa($7A62);
	setJa($7A69);
	setJa($9F9D);
	setJa($7A70);
	setJa($7A79);
	setJa($7A7D);
	setJa($7A88);
	setJa($7A97);
	setJa($7A95);
	setJa($7A98);
	setJa($7A96);
	setJa($7AA9);
	setJa($7AC8);
	setJa($7AB0);
	setJa($7AB6);
	setJa($7AC5);
	setJa($7AC4);
	setJa($7ABF);
	setJa($9083);
	setJa($7AC7);
	setJa($7ACA);
	setJa($7ACD);
	setJa($7ACF);
	setJa($7AD5);
	setJa($7AD3);
	setJa($7AD9);
	setJa($7ADA);
	setJa($7ADD);
	setJa($7AE1);
	setJa($7AE2);
	setJa($7AE6);
	setJa($7AED);
	setJa($7AF0);
	setJa($7B02);
	setJa($7B0F);
	setJa($7B0A);
	setJa($7B06);
	setJa($7B33);
	setJa($7B18);
	setJa($7B19);
	setJa($7B1E);
	setJa($7B35);
	setJa($7B28);
	setJa($7B36);
	setJa($7B50);
	setJa($7B7A);
	setJa($7B04);
	setJa($7B4D);
	setJa($7B0B);
	setJa($7B4C);
	setJa($7B45);
	setJa($7B75);
	setJa($7B65);
	setJa($7B74);
	setJa($7B67);
	setJa($7B70);
	setJa($7B71);
	setJa($7B6C);
	setJa($7B6E);
	setJa($7B9D);
	setJa($7B98);
	setJa($7B9F);
	setJa($7B8D);
	setJa($7B9C);
	setJa($7B9A);
	setJa($7B8B);
	setJa($7B92);
	setJa($7B8F);
	setJa($7B5D);
	setJa($7B99);
	setJa($7BCB);
	setJa($7BC1);
	setJa($7BCC);
	setJa($7BCF);
	setJa($7BB4);
	setJa($7BC6);
	setJa($7BDD);
	setJa($7BE9);
	setJa($7C11);
	setJa($7C14);
	setJa($7BE6);
	setJa($7BE5);
	setJa($7C60);
	setJa($7C00);
	setJa($7C07);
	setJa($7C13);
	setJa($7BF3);
	setJa($7BF7);
	setJa($7C17);
	setJa($7C0D);
	setJa($7BF6);
	setJa($7C23);
	setJa($7C27);
	setJa($7C2A);
	setJa($7C1F);
	setJa($7C37);
	setJa($7C2B);
	setJa($7C3D);
	setJa($7C4C);
	setJa($7C43);
	setJa($7C54);
	setJa($7C4F);
	setJa($7C40);
	setJa($7C50);
	setJa($7C58);
	setJa($7C5F);
	setJa($7C64);
	setJa($7C56);
	setJa($7C65);
	setJa($7C6C);
	setJa($7C75);
	setJa($7C83);
	setJa($7C90);
	setJa($7CA4);
	setJa($7CAD);
	setJa($7CA2);
	setJa($7CAB);
	setJa($7CA1);
	setJa($7CA8);
	setJa($7CB3);
	setJa($7CB2);
	setJa($7CB1);
	setJa($7CAE);
	setJa($7CB9);
	setJa($7CBD);
	setJa($7CC0);
	setJa($7CC5);
	setJa($7CC2);
	setJa($7CD8);
	setJa($7CD2);
	setJa($7CDC);
	setJa($7CE2);
	setJa($9B3B);
	setJa($7CEF);
	setJa($7CF2);
	setJa($7CF4);
	setJa($7CF6);
	setJa($7CFA);
	setJa($7D06);
	setJa($7D02);
	setJa($7D1C);
	setJa($7D15);
	setJa($7D0A);
	setJa($7D45);
	setJa($7D4B);
	setJa($7D2E);
	setJa($7D32);
	setJa($7D3F);
	setJa($7D35);
	setJa($7D46);
	setJa($7D73);
	setJa($7D56);
	setJa($7D4E);
	setJa($7D72);
	setJa($7D68);
	setJa($7D6E);
	setJa($7D4F);
	setJa($7D63);
	setJa($7D93);
	setJa($7D89);
	setJa($7D5B);
	setJa($7D8F);
	setJa($7D7D);
	setJa($7D9B);
	setJa($7DBA);
	setJa($7DAE);
	setJa($7DA3);
	setJa($7DB5);
	setJa($7DC7);
	setJa($7DBD);
	setJa($7DAB);
	setJa($7E3D);
	setJa($7DA2);
	setJa($7DAF);
	setJa($7DDC);
	setJa($7DB8);
	setJa($7D9F);
	setJa($7DB0);
	setJa($7DD8);
	setJa($7DDD);
	setJa($7DE4);
	setJa($7DDE);
	setJa($7DFB);
	setJa($7DF2);
	setJa($7DE1);
	setJa($7E05);
	setJa($7E0A);
	setJa($7E23);
	setJa($7E21);
	setJa($7E12);
	setJa($7E31);
	setJa($7E1F);
	setJa($7E09);
	setJa($7E0B);
	setJa($7E22);
	setJa($7E46);
	setJa($7E66);
	setJa($7E3B);
	setJa($7E35);
	setJa($7E39);
	setJa($7E43);
	setJa($7E37);
	setJa($7E32);
	setJa($7E3A);
	setJa($7E67);
	setJa($7E5D);
	setJa($7E56);
	setJa($7E5E);
	setJa($7E59);
	setJa($7E5A);
	setJa($7E79);
	setJa($7E6A);
	setJa($7E69);
	setJa($7E7C);
	setJa($7E7B);
	setJa($7E83);
	setJa($7DD5);
	setJa($7E7D);
	setJa($8FAE);
	setJa($7E7F);
	setJa($7E88);
	setJa($7E89);
	setJa($7E8C);
	setJa($7E92);
	setJa($7E90);
	setJa($7E93);
	setJa($7E94);
	setJa($7E96);
	setJa($7E8E);
	setJa($7E9B);
	setJa($7E9C);
	setJa($7F38);
	setJa($7F3A);
	setJa($7F45);
	setJa($7F4C);
	setJa($7F4D);
	setJa($7F4E);
	setJa($7F50);
	setJa($7F51);
	setJa($7F55);
	setJa($7F54);
	setJa($7F58);
	setJa($7F5F);
	setJa($7F60);
	setJa($7F68);
	setJa($7F69);
	setJa($7F67);
	setJa($7F78);
	setJa($7F82);
	setJa($7F86);
	setJa($7F83);
	setJa($7F88);
	setJa($7F87);
	setJa($7F8C);
	setJa($7F94);
	setJa($7F9E);
	setJa($7F9D);
	setJa($7F9A);
	setJa($7FA3);
	setJa($7FAF);
	setJa($7FB2);
	setJa($7FB9);
	setJa($7FAE);
	setJa($7FB6);
	setJa($7FB8);
	setJa($8B71);
	setJa($7FC5);
	setJa($7FC6);
	setJa($7FCA);
	setJa($7FD5);
	setJa($7FD4);
	setJa($7FE1);
	setJa($7FE6);
	setJa($7FE9);
	setJa($7FF3);
	setJa($7FF9);
	setJa($98DC);
	setJa($8006);
	setJa($8004);
	setJa($800B);
	setJa($8012);
	setJa($8018);
	setJa($8019);
	setJa($801C);
	setJa($8021);
	setJa($8028);
	setJa($803F);
	setJa($803B);
	setJa($804A);
	setJa($8046);
	setJa($8052);
	setJa($8058);
	setJa($805A);
	setJa($805F);
	setJa($8062);
	setJa($8068);
	setJa($8073);
	setJa($8072);
	setJa($8070);
	setJa($8076);
	setJa($8079);
	setJa($807D);
	setJa($807F);
	setJa($8084);
	setJa($8086);
	setJa($8085);
	setJa($809B);
	setJa($8093);
	setJa($809A);
	setJa($80AD);
	setJa($5190);
	setJa($80AC);
	setJa($80DB);
	setJa($80E5);
	setJa($80D9);
	setJa($80DD);
	setJa($80C4);
	setJa($80DA);
	setJa($80D6);
	setJa($8109);
	setJa($80EF);
	setJa($80F1);
	setJa($811B);
	setJa($8129);
	setJa($8123);
	setJa($812F);
	setJa($814B);
	setJa($968B);
	setJa($8146);
	setJa($813E);
	setJa($8153);
	setJa($8151);
	setJa($80FC);
	setJa($8171);
	setJa($816E);
	setJa($8165);
	setJa($8166);
	setJa($8174);
	setJa($8183);
	setJa($8188);
	setJa($818A);
	setJa($8180);
	setJa($8182);
	setJa($81A0);
	setJa($8195);
	setJa($81A4);
	setJa($81A3);
	setJa($815F);
	setJa($8193);
	setJa($81A9);
	setJa($81B0);
	setJa($81B5);
	setJa($81BE);
	setJa($81B8);
	setJa($81BD);
	setJa($81C0);
	setJa($81C2);
	setJa($81BA);
	setJa($81C9);
	setJa($81CD);
	setJa($81D1);
	setJa($81D9);
	setJa($81D8);
	setJa($81C8);
	setJa($81DA);
	setJa($81DF);
	setJa($81E0);
	setJa($81E7);
	setJa($81FA);
	setJa($81FB);
	setJa($81FE);
	setJa($8201);
	setJa($8202);
	setJa($8205);
	setJa($8207);
	setJa($820A);
	setJa($820D);
	setJa($8210);
	setJa($8216);
	setJa($8229);
	setJa($822B);
	setJa($8238);
	setJa($8233);
	setJa($8240);
	setJa($8259);
	setJa($8258);
	setJa($825D);
	setJa($825A);
	setJa($825F);
	setJa($8264);
	setJa($8262);
	setJa($8268);
	setJa($826A);
	setJa($826B);
	setJa($822E);
	setJa($8271);
	setJa($8277);
	setJa($8278);
	setJa($827E);
	setJa($828D);
	setJa($8292);
	setJa($82AB);
	setJa($829F);
	setJa($82BB);
	setJa($82AC);
	setJa($82E1);
	setJa($82E3);
	setJa($82DF);
	setJa($82D2);
	setJa($82F4);
	setJa($82F3);
	setJa($82FA);
	setJa($8393);
	setJa($8303);
	setJa($82FB);
	setJa($82F9);
	setJa($82DE);
	setJa($8306);
	setJa($82DC);
	setJa($8309);
	setJa($82D9);
	setJa($8335);
	setJa($8334);
	setJa($8316);
	setJa($8332);
	setJa($8331);
	setJa($8340);
	setJa($8339);
	setJa($8350);
	setJa($8345);
	setJa($832F);
	setJa($832B);
	setJa($8317);
	setJa($8318);
	setJa($8385);
	setJa($839A);
	setJa($83AA);
	setJa($839F);
	setJa($83A2);
	setJa($8396);
	setJa($8323);
	setJa($838E);
	setJa($8387);
	setJa($838A);
	setJa($837C);
	setJa($83B5);
	setJa($8373);
	setJa($8375);
	setJa($83A0);
	setJa($8389);
	setJa($83A8);
	setJa($83F4);
	setJa($8413);
	setJa($83EB);
	setJa($83CE);
	setJa($83FD);
	setJa($8403);
	setJa($83D8);
	setJa($840B);
	setJa($83C1);
	setJa($83F7);
	setJa($8407);
	setJa($83E0);
	setJa($83F2);
	setJa($840D);
	setJa($8422);
	setJa($8420);
	setJa($83BD);
	setJa($8438);
	setJa($8506);
	setJa($83FB);
	setJa($846D);
	setJa($842A);
	setJa($843C);
	setJa($855A);
	setJa($8484);
	setJa($8477);
	setJa($846B);
	setJa($84AD);
	setJa($846E);
	setJa($8482);
	setJa($8469);
	setJa($8446);
	setJa($842C);
	setJa($846F);
	setJa($8479);
	setJa($8435);
	setJa($84CA);
	setJa($8462);
	setJa($84B9);
	setJa($84BF);
	setJa($849F);
	setJa($84D9);
	setJa($84CD);
	setJa($84BB);
	setJa($84DA);
	setJa($84D0);
	setJa($84C1);
	setJa($84C6);
	setJa($84D6);
	setJa($84A1);
	setJa($8521);
	setJa($84FF);
	setJa($84F4);
	setJa($8517);
	setJa($8518);
	setJa($852C);
	setJa($851F);
	setJa($8515);
	setJa($8514);
	setJa($84FC);
	setJa($8540);
	setJa($8563);
	setJa($8558);
	setJa($8548);
	setJa($8541);
	setJa($8602);
	setJa($854B);
	setJa($8555);
	setJa($8580);
	setJa($85A4);
	setJa($8588);
	setJa($8591);
	setJa($858A);
	setJa($85A8);
	setJa($856D);
	setJa($8594);
	setJa($859B);
	setJa($85EA);
	setJa($8587);
	setJa($859C);
	setJa($8577);
	setJa($857E);
	setJa($8590);
	setJa($85C9);
	setJa($85BA);
	setJa($85CF);
	setJa($85B9);
	setJa($85D0);
	setJa($85D5);
	setJa($85DD);
	setJa($85E5);
	setJa($85DC);
	setJa($85F9);
	setJa($860A);
	setJa($8613);
	setJa($860B);
	setJa($85FE);
	setJa($85FA);
	setJa($8606);
	setJa($8622);
	setJa($861A);
	setJa($8630);
	setJa($863F);
	setJa($864D);
	setJa($4E55);
	setJa($8654);
	setJa($865F);
	setJa($8667);
	setJa($8671);
	setJa($8693);
	setJa($86A3);
	setJa($86A9);
	setJa($86AA);
	setJa($868B);
	setJa($868C);
	setJa($86B6);
	setJa($86AF);
	setJa($86C4);
	setJa($86C6);
	setJa($86B0);
	setJa($86C9);
	setJa($8823);
	setJa($86AB);
	setJa($86D4);
	setJa($86DE);
	setJa($86E9);
	setJa($86EC);
	setJa($86DF);
	setJa($86DB);
	setJa($86EF);
	setJa($8712);
	setJa($8706);
	setJa($8708);
	setJa($8700);
	setJa($8703);
	setJa($86FB);
	setJa($8711);
	setJa($8709);
	setJa($870D);
	setJa($86F9);
	setJa($870A);
	setJa($8734);
	setJa($873F);
	setJa($8737);
	setJa($873B);
	setJa($8725);
	setJa($8729);
	setJa($871A);
	setJa($8760);
	setJa($875F);
	setJa($8778);
	setJa($874C);
	setJa($874E);
	setJa($8774);
	setJa($8757);
	setJa($8768);
	setJa($876E);
	setJa($8759);
	setJa($8753);
	setJa($8763);
	setJa($876A);
	setJa($8805);
	setJa($87A2);
	setJa($879F);
	setJa($8782);
	setJa($87AF);
	setJa($87CB);
	setJa($87BD);
	setJa($87C0);
	setJa($87D0);
	setJa($96D6);
	setJa($87AB);
	setJa($87C4);
	setJa($87B3);
	setJa($87C7);
	setJa($87C6);
	setJa($87BB);
	setJa($87EF);
	setJa($87F2);
	setJa($87E0);
	setJa($880F);
	setJa($880D);
	setJa($87FE);
	setJa($87F6);
	setJa($87F7);
	setJa($880E);
	setJa($87D2);
	setJa($8811);
	setJa($8816);
	setJa($8815);
	setJa($8822);
	setJa($8821);
	setJa($8831);
	setJa($8836);
	setJa($8839);
	setJa($8827);
	setJa($883B);
	setJa($8844);
	setJa($8842);
	setJa($8852);
	setJa($8859);
	setJa($885E);
	setJa($8862);
	setJa($886B);
	setJa($8881);
	setJa($887E);
	setJa($889E);
	setJa($8875);
	setJa($887D);
	setJa($88B5);
	setJa($8872);
	setJa($8882);
	setJa($8897);
	setJa($8892);
	setJa($88AE);
	setJa($8899);
	setJa($88A2);
	setJa($888D);
	setJa($88A4);
	setJa($88B0);
	setJa($88BF);
	setJa($88B1);
	setJa($88C3);
	setJa($88C4);
	setJa($88D4);
	setJa($88D8);
	setJa($88D9);
	setJa($88DD);
	setJa($88F9);
	setJa($8902);
	setJa($88FC);
	setJa($88F4);
	setJa($88E8);
	setJa($88F2);
	setJa($8904);
	setJa($890C);
	setJa($890A);
	setJa($8913);
	setJa($8943);
	setJa($891E);
	setJa($8925);
	setJa($892A);
	setJa($892B);
	setJa($8941);
	setJa($8944);
	setJa($893B);
	setJa($8936);
	setJa($8938);
	setJa($894C);
	setJa($891D);
	setJa($8960);
	setJa($895E);
	setJa($8966);
	setJa($8964);
	setJa($896D);
	setJa($896A);
	setJa($896F);
	setJa($8974);
	setJa($8977);
	setJa($897E);
	setJa($8983);
	setJa($8988);
	setJa($898A);
	setJa($8993);
	setJa($8998);
	setJa($89A1);
	setJa($89A9);
	setJa($89A6);
	setJa($89AC);
	setJa($89AF);
	setJa($89B2);
	setJa($89BA);
	setJa($89BD);
	setJa($89BF);
	setJa($89C0);
	setJa($89DA);
	setJa($89DC);
	setJa($89DD);
	setJa($89E7);
	setJa($89F4);
	setJa($89F8);
	setJa($8A03);
	setJa($8A16);
	setJa($8A10);
	setJa($8A0C);
	setJa($8A1B);
	setJa($8A1D);
	setJa($8A25);
	setJa($8A36);
	setJa($8A41);
	setJa($8A5B);
	setJa($8A52);
	setJa($8A46);
	setJa($8A48);
	setJa($8A7C);
	setJa($8A6D);
	setJa($8A6C);
	setJa($8A62);
	setJa($8A85);
	setJa($8A82);
	setJa($8A84);
	setJa($8AA8);
	setJa($8AA1);
	setJa($8A91);
	setJa($8AA5);
	setJa($8AA6);
	setJa($8A9A);
	setJa($8AA3);
	setJa($8AC4);
	setJa($8ACD);
	setJa($8AC2);
	setJa($8ADA);
	setJa($8AEB);
	setJa($8AF3);
	setJa($8AE7);
	setJa($8AE4);
	setJa($8AF1);
	setJa($8B14);
	setJa($8AE0);
	setJa($8AE2);
	setJa($8AF7);
	setJa($8ADE);
	setJa($8ADB);
	setJa($8B0C);
	setJa($8B07);
	setJa($8B1A);
	setJa($8AE1);
	setJa($8B16);
	setJa($8B10);
	setJa($8B17);
	setJa($8B20);
	setJa($8B33);
	setJa($97AB);
	setJa($8B26);
	setJa($8B2B);
	setJa($8B3E);
	setJa($8B28);
	setJa($8B41);
	setJa($8B4C);
	setJa($8B4F);
	setJa($8B4E);
	setJa($8B49);
	setJa($8B56);
	setJa($8B5B);
	setJa($8B5A);
	setJa($8B6B);
	setJa($8B5F);
	setJa($8B6C);
	setJa($8B6F);
	setJa($8B74);
	setJa($8B7D);
	setJa($8B80);
	setJa($8B8C);
	setJa($8B8E);
	setJa($8B92);
	setJa($8B93);
	setJa($8B96);
	setJa($8B99);
	setJa($8B9A);
	setJa($8C3A);
	setJa($8C41);
	setJa($8C3F);
	setJa($8C48);
	setJa($8C4C);
	setJa($8C4E);
	setJa($8C50);
	setJa($8C55);
	setJa($8C62);
	setJa($8C6C);
	setJa($8C78);
	setJa($8C7A);
	setJa($8C82);
	setJa($8C89);
	setJa($8C85);
	setJa($8C8A);
	setJa($8C8D);
	setJa($8C8E);
	setJa($8C94);
	setJa($8C7C);
	setJa($8C98);
	setJa($621D);
	setJa($8CAD);
	setJa($8CAA);
	setJa($8CBD);
	setJa($8CB2);
	setJa($8CB3);
	setJa($8CAE);
	setJa($8CB6);
	setJa($8CC8);
	setJa($8CC1);
	setJa($8CE4);
	setJa($8CE3);
	setJa($8CDA);
	setJa($8CFD);
	setJa($8CFA);
	setJa($8CFB);
	setJa($8D04);
	setJa($8D05);
	setJa($8D0A);
	setJa($8D07);
	setJa($8D0F);
	setJa($8D0D);
	setJa($8D10);
	setJa($9F4E);
	setJa($8D13);
	setJa($8CCD);
	setJa($8D14);
	setJa($8D16);
	setJa($8D67);
	setJa($8D6D);
	setJa($8D71);
	setJa($8D73);
	setJa($8D81);
	setJa($8D99);
	setJa($8DC2);
	setJa($8DBE);
	setJa($8DBA);
	setJa($8DCF);
	setJa($8DDA);
	setJa($8DD6);
	setJa($8DCC);
	setJa($8DDB);
	setJa($8DCB);
	setJa($8DEA);
	setJa($8DEB);
	setJa($8DDF);
	setJa($8DE3);
	setJa($8DFC);
	setJa($8E08);
	setJa($8E09);
	setJa($8DFF);
	setJa($8E1D);
	setJa($8E1E);
	setJa($8E10);
	setJa($8E1F);
	setJa($8E42);
	setJa($8E35);
	setJa($8E30);
	setJa($8E34);
	setJa($8E4A);
	setJa($8E47);
	setJa($8E49);
	setJa($8E4C);
	setJa($8E50);
	setJa($8E48);
	setJa($8E59);
	setJa($8E64);
	setJa($8E60);
	setJa($8E2A);
	setJa($8E63);
	setJa($8E55);
	setJa($8E76);
	setJa($8E72);
	setJa($8E7C);
	setJa($8E81);
	setJa($8E87);
	setJa($8E85);
	setJa($8E84);
	setJa($8E8B);
	setJa($8E8A);
	setJa($8E93);
	setJa($8E91);
	setJa($8E94);
	setJa($8E99);
	setJa($8EAA);
	setJa($8EA1);
	setJa($8EAC);
	setJa($8EB0);
	setJa($8EC6);
	setJa($8EB1);
	setJa($8EBE);
	setJa($8EC5);
	setJa($8EC8);
	setJa($8ECB);
	setJa($8EDB);
	setJa($8EE3);
	setJa($8EFC);
	setJa($8EFB);
	setJa($8EEB);
	setJa($8EFE);
	setJa($8F0A);
	setJa($8F05);
	setJa($8F15);
	setJa($8F12);
	setJa($8F19);
	setJa($8F13);
	setJa($8F1C);
	setJa($8F1F);
	setJa($8F1B);
	setJa($8F0C);
	setJa($8F26);
	setJa($8F33);
	setJa($8F3B);
	setJa($8F39);
	setJa($8F45);
	setJa($8F42);
	setJa($8F3E);
	setJa($8F4C);
	setJa($8F49);
	setJa($8F46);
	setJa($8F4E);
	setJa($8F57);
	setJa($8F5C);
	setJa($8F62);
	setJa($8F63);
	setJa($8F64);
	setJa($8F9C);
	setJa($8F9F);
	setJa($8FA3);
	setJa($8FAD);
	setJa($8FAF);
	setJa($8FB7);
	setJa($8FDA);
	setJa($8FE5);
	setJa($8FE2);
	setJa($8FEA);
	setJa($8FEF);
	setJa($9087);
	setJa($8FF4);
	setJa($9005);
	setJa($8FF9);
	setJa($8FFA);
	setJa($9011);
	setJa($9015);
	setJa($9021);
	setJa($900D);
	setJa($901E);
	setJa($9016);
	setJa($900B);
	setJa($9027);
	setJa($9036);
	setJa($9035);
	setJa($9039);
	setJa($8FF8);
	setJa($904F);
	setJa($9050);
	setJa($9051);
	setJa($9052);
	setJa($900E);
	setJa($9049);
	setJa($903E);
	setJa($9056);
	setJa($9058);
	setJa($905E);
	setJa($9068);
	setJa($906F);
	setJa($9076);
	setJa($96A8);
	setJa($9072);
	setJa($9082);
	setJa($907D);
	setJa($9081);
	setJa($9080);
	setJa($908A);
	setJa($9089);
	setJa($908F);
	setJa($90A8);
	setJa($90AF);
	setJa($90B1);
	setJa($90B5);
	setJa($90E2);
	setJa($90E4);
	setJa($6248);
	setJa($90DB);
	setJa($9102);
	setJa($9112);
	setJa($9119);
	setJa($9132);
	setJa($9130);
	setJa($914A);
	setJa($9156);
	setJa($9158);
	setJa($9163);
	setJa($9165);
	setJa($9169);
	setJa($9173);
	setJa($9172);
	setJa($918B);
	setJa($9189);
	setJa($9182);
	setJa($91A2);
	setJa($91AB);
	setJa($91AF);
	setJa($91AA);
	setJa($91B5);
	setJa($91B4);
	setJa($91BA);
	setJa($91C0);
	setJa($91C1);
	setJa($91C9);
	setJa($91CB);
	setJa($91D0);
	setJa($91D6);
	setJa($91DF);
	setJa($91E1);
	setJa($91DB);
	setJa($91FC);
	setJa($91F5);
	setJa($91F6);
	setJa($921E);
	setJa($91FF);
	setJa($9214);
	setJa($922C);
	setJa($9215);
	setJa($9211);
	setJa($925E);
	setJa($9257);
	setJa($9245);
	setJa($9249);
	setJa($9264);
	setJa($9248);
	setJa($9295);
	setJa($923F);
	setJa($924B);
	setJa($9250);
	setJa($929C);
	setJa($9296);
	setJa($9293);
	setJa($929B);
	setJa($925A);
	setJa($92CF);
	setJa($92B9);
	setJa($92B7);
	setJa($92E9);
	setJa($930F);
	setJa($92FA);
	setJa($9344);
	setJa($932E);
	setJa($9319);
	setJa($9322);
	setJa($931A);
	setJa($9323);
	setJa($933A);
	setJa($9335);
	setJa($933B);
	setJa($935C);
	setJa($9360);
	setJa($937C);
	setJa($936E);
	setJa($9356);
	setJa($93B0);
	setJa($93AC);
	setJa($93AD);
	setJa($9394);
	setJa($93B9);
	setJa($93D6);
	setJa($93D7);
	setJa($93E8);
	setJa($93E5);
	setJa($93D8);
	setJa($93C3);
	setJa($93DD);
	setJa($93D0);
	setJa($93C8);
	setJa($93E4);
	setJa($941A);
	setJa($9414);
	setJa($9413);
	setJa($9403);
	setJa($9407);
	setJa($9410);
	setJa($9436);
	setJa($942B);
	setJa($9435);
	setJa($9421);
	setJa($943A);
	setJa($9441);
	setJa($9452);
	setJa($9444);
	setJa($945B);
	setJa($9460);
	setJa($9462);
	setJa($945E);
	setJa($946A);
	setJa($9229);
	setJa($9470);
	setJa($9475);
	setJa($9477);
	setJa($947D);
	setJa($945A);
	setJa($947C);
	setJa($947E);
	setJa($9481);
	setJa($947F);
	setJa($9582);
	setJa($9587);
	setJa($958A);
	setJa($9594);
	setJa($9596);
	setJa($9598);
	setJa($9599);
	setJa($95A0);
	setJa($95A8);
	setJa($95A7);
	setJa($95AD);
	setJa($95BC);
	setJa($95BB);
	setJa($95B9);
	setJa($95BE);
	setJa($95CA);
	setJa($6FF6);
	setJa($95C3);
	setJa($95CD);
	setJa($95CC);
	setJa($95D5);
	setJa($95D4);
	setJa($95D6);
	setJa($95DC);
	setJa($95E1);
	setJa($95E5);
	setJa($95E2);
	setJa($9621);
	setJa($9628);
	setJa($962E);
	setJa($962F);
	setJa($9642);
	setJa($964C);
	setJa($964F);
	setJa($964B);
	setJa($9677);
	setJa($965C);
	setJa($965E);
	setJa($965D);
	setJa($965F);
	setJa($9666);
	setJa($9672);
	setJa($966C);
	setJa($968D);
	setJa($9698);
	setJa($9695);
	setJa($9697);
	setJa($96AA);
	setJa($96A7);
	setJa($96B1);
	setJa($96B2);
	setJa($96B0);
	setJa($96B4);
	setJa($96B6);
	setJa($96B8);
	setJa($96B9);
	setJa($96CE);
	setJa($96CB);
	setJa($96C9);
	setJa($96CD);
	setJa($894D);
	setJa($96DC);
	setJa($970D);
	setJa($96D5);
	setJa($96F9);
	setJa($9704);
	setJa($9706);
	setJa($9708);
	setJa($9713);
	setJa($970E);
	setJa($9711);
	setJa($970F);
	setJa($9716);
	setJa($9719);
	setJa($9724);
	setJa($972A);
	setJa($9730);
	setJa($9739);
	setJa($973D);
	setJa($973E);
	setJa($9744);
	setJa($9746);
	setJa($9748);
	setJa($9742);
	setJa($9749);
	setJa($975C);
	setJa($9760);
	setJa($9764);
	setJa($9766);
	setJa($9768);
	setJa($52D2);
	setJa($976B);
	setJa($9771);
	setJa($9779);
	setJa($9785);
	setJa($977C);
	setJa($9781);
	setJa($977A);
	setJa($9786);
	setJa($978B);
	setJa($978F);
	setJa($9790);
	setJa($979C);
	setJa($97A8);
	setJa($97A6);
	setJa($97A3);
	setJa($97B3);
	setJa($97B4);
	setJa($97C3);
	setJa($97C6);
	setJa($97C8);
	setJa($97CB);
	setJa($97DC);
	setJa($97ED);
	setJa($9F4F);
	setJa($97F2);
	setJa($7ADF);
	setJa($97F6);
	setJa($97F5);
	setJa($980F);
	setJa($980C);
	setJa($9838);
	setJa($9824);
	setJa($9821);
	setJa($9837);
	setJa($983D);
	setJa($9846);
	setJa($984F);
	setJa($984B);
	setJa($986B);
	setJa($986F);
	setJa($9870);
	setJa($9871);
	setJa($9874);
	setJa($9873);
	setJa($98AA);
	setJa($98AF);
	setJa($98B1);
	setJa($98B6);
	setJa($98C4);
	setJa($98C3);
	setJa($98C6);
	setJa($98E9);
	setJa($98EB);
	setJa($9903);
	setJa($9909);
	setJa($9912);
	setJa($9914);
	setJa($9918);
	setJa($9921);
	setJa($991D);
	setJa($991E);
	setJa($9924);
	setJa($9920);
	setJa($992C);
	setJa($992E);
	setJa($993D);
	setJa($993E);
	setJa($9942);
	setJa($9949);
	setJa($9945);
	setJa($9950);
	setJa($994B);
	setJa($9951);
	setJa($9952);
	setJa($994C);
	setJa($9955);
	setJa($9997);
	setJa($9998);
	setJa($99A5);
	setJa($99AD);
	setJa($99AE);
	setJa($99BC);
	setJa($99DF);
	setJa($99DB);
	setJa($99DD);
	setJa($99D8);
	setJa($99D1);
	setJa($99ED);
	setJa($99EE);
	setJa($99F1);
	setJa($99F2);
	setJa($99FB);
	setJa($99F8);
	setJa($9A01);
	setJa($9A0F);
	setJa($9A05);
	setJa($99E2);
	setJa($9A19);
	setJa($9A2B);
	setJa($9A37);
	setJa($9A45);
	setJa($9A42);
	setJa($9A40);
	setJa($9A43);
	setJa($9A3E);
	setJa($9A55);
	setJa($9A4D);
	setJa($9A5B);
	setJa($9A57);
	setJa($9A5F);
	setJa($9A62);
	setJa($9A65);
	setJa($9A64);
	setJa($9A69);
	setJa($9A6B);
	setJa($9A6A);
	setJa($9AAD);
	setJa($9AB0);
	setJa($9ABC);
	setJa($9AC0);
	setJa($9ACF);
	setJa($9AD1);
	setJa($9AD3);
	setJa($9AD4);
	setJa($9ADE);
	setJa($9ADF);
	setJa($9AE2);
	setJa($9AE3);
	setJa($9AE6);
	setJa($9AEF);
	setJa($9AEB);
	setJa($9AEE);
	setJa($9AF4);
	setJa($9AF1);
	setJa($9AF7);
	setJa($9AFB);
	setJa($9B06);
	setJa($9B18);
	setJa($9B1A);
	setJa($9B1F);
	setJa($9B22);
	setJa($9B23);
	setJa($9B25);
	setJa($9B27);
	setJa($9B28);
	setJa($9B29);
	setJa($9B2A);
	setJa($9B2E);
	setJa($9B2F);
	setJa($9B32);
	setJa($9B44);
	setJa($9B43);
	setJa($9B4F);
	setJa($9B4D);
	setJa($9B4E);
	setJa($9B51);
	setJa($9B58);
	setJa($9B74);
	setJa($9B93);
	setJa($9B83);
	setJa($9B91);
	setJa($9B96);
	setJa($9B97);
	setJa($9B9F);
	setJa($9BA0);
	setJa($9BA8);
	setJa($9BB4);
	setJa($9BC0);
	setJa($9BCA);
	setJa($9BB9);
	setJa($9BC6);
	setJa($9BCF);
	setJa($9BD1);
	setJa($9BD2);
	setJa($9BE3);
	setJa($9BE2);
	setJa($9BE4);
	setJa($9BD4);
	setJa($9BE1);
	setJa($9C3A);
	setJa($9BF2);
	setJa($9BF1);
	setJa($9BF0);
	setJa($9C15);
	setJa($9C14);
	setJa($9C09);
	setJa($9C13);
	setJa($9C0C);
	setJa($9C06);
	setJa($9C08);
	setJa($9C12);
	setJa($9C0A);
	setJa($9C04);
	setJa($9C2E);
	setJa($9C1B);
	setJa($9C25);
	setJa($9C24);
	setJa($9C21);
	setJa($9C30);
	setJa($9C47);
	setJa($9C32);
	setJa($9C46);
	setJa($9C3E);
	setJa($9C5A);
	setJa($9C60);
	setJa($9C67);
	setJa($9C76);
	setJa($9C78);
	setJa($9CE7);
	setJa($9CEC);
	setJa($9CF0);
	setJa($9D09);
	setJa($9D08);
	setJa($9CEB);
	setJa($9D03);
	setJa($9D06);
	setJa($9D2A);
	setJa($9D26);
	setJa($9DAF);
	setJa($9D23);
	setJa($9D1F);
	setJa($9D44);
	setJa($9D15);
	setJa($9D12);
	setJa($9D41);
	setJa($9D3F);
	setJa($9D3E);
	setJa($9D46);
	setJa($9D48);
	setJa($9D5D);
	setJa($9D5E);
	setJa($9D64);
	setJa($9D51);
	setJa($9D50);
	setJa($9D59);
	setJa($9D72);
	setJa($9D89);
	setJa($9D87);
	setJa($9DAB);
	setJa($9D6F);
	setJa($9D7A);
	setJa($9D9A);
	setJa($9DA4);
	setJa($9DA9);
	setJa($9DB2);
	setJa($9DC4);
	setJa($9DC1);
	setJa($9DBB);
	setJa($9DB8);
	setJa($9DBA);
	setJa($9DC6);
	setJa($9DCF);
	setJa($9DC2);
	setJa($9DD9);
	setJa($9DD3);
	setJa($9DF8);
	setJa($9DE6);
	setJa($9DED);
	setJa($9DEF);
	setJa($9DFD);
	setJa($9E1A);
	setJa($9E1B);
	setJa($9E1E);
	setJa($9E75);
	setJa($9E79);
	setJa($9E7D);
	setJa($9E81);
	setJa($9E88);
	setJa($9E8B);
	setJa($9E8C);
	setJa($9E92);
	setJa($9E95);
	setJa($9E91);
	setJa($9E9D);
	setJa($9EA5);
	setJa($9EA9);
	setJa($9EB8);
	setJa($9EAA);
	setJa($9EAD);
	setJa($9761);
	setJa($9ECC);
	setJa($9ECE);
	setJa($9ECF);
	setJa($9ED0);
	setJa($9ED4);
	setJa($9EDC);
	setJa($9EDE);
	setJa($9EDD);
	setJa($9EE0);
	setJa($9EE5);
	setJa($9EE8);
	setJa($9EEF);
	setJa($9EF4);
	setJa($9EF6);
	setJa($9EF7);
	setJa($9EF9);
	setJa($9EFB);
	setJa($9EFC);
	setJa($9EFD);
	setJa($9F07);
	setJa($9F08);
	setJa($76B7);
	setJa($9F15);
	setJa($9F21);
	setJa($9F2C);
	setJa($9F3E);
	setJa($9F4A);
	setJa($9F52);
	setJa($9F54);
	setJa($9F63);
	setJa($9F5F);
	setJa($9F60);
	setJa($9F61);
	setJa($9F66);
	setJa($9F67);
	setJa($9F6C);
	setJa($9F6A);
	setJa($9F77);
	setJa($9F72);
	setJa($9F76);
	setJa($9F95);
	setJa($9F9C);
	setJa($9FA0);
	setJa($582F);
	setJa($69C7);
	setJa($9059);
	setJa($7464);
	setJa($51DC);
	setJa($7199);
end.
